@@ -1,7 +1,7 @@
 /*
  *  Copyright (C) 1999-2002 Bernd Gehrmann
  *                          bernd@physik.hu-berlin.de
- *  Copyright (c) 2003-2004 Christian Loose <christian.loose@kdemail.net>
+ *  Copyright (c) 2003-2007 Christian Loose <christian.loose@kdemail.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,50 +20,44 @@
 
 
 #include "protocolview.h"
+#include "protocolviewadaptor.h"
+
+#include <QAction>
+#include <QMenu>
+//#include <QTextDocument>
 
-#include <qdir.h>
-#include <qpopupmenu.h>
-#include <dcopref.h>
-#include <kconfig.h>
 #include <klocale.h>
 #include <kmessagebox.h>
 
 #include "cervisiapart.h"
-#include "cvsjob_stub.h"
+#include "cervisiasettings.h"
+#include "cvsjobinterface.h"
 
 
-ProtocolView::ProtocolView(const QCString& appId, QWidget *parent, const char *name)
-    : QTextEdit(parent, name)
+ProtocolView::ProtocolView(const QString& appId, QWidget *parent)
+    : QTextEdit(parent)
     , job(0)
     , m_isUpdateJob(false)
 {
+    new ProtocolviewAdaptor(this);
+    QDBusConnection::sessionBus().registerObject( "/ProtocolView", this );
+
     setReadOnly(true);
     setUndoRedoEnabled(false);
     setTabChangesFocus(true);
-    setTextFormat(Qt::LogText);
 
-    KConfig *config = CervisiaPart::config();
-    config->setGroup("LookAndFeel");
-    setFont(config->readFontEntry("ProtocolFont"));
+    //kDebug(8050) << "protocol view appId :" << appId;
 
-    config->setGroup("Colors");
-    QColor defaultColor = QColor(255, 130, 130);
-    conflictColor=config->readColorEntry("Conflict",&defaultColor);
-    defaultColor=QColor(130, 130, 255);
-    localChangeColor=config->readColorEntry("LocalChange",&defaultColor);
-    defaultColor=QColor(70, 210, 70);
-    remoteChangeColor=config->readColorEntry("RemoteChange",&defaultColor);
+    job = new OrgKdeCervisiaCvsserviceCvsjobInterface(appId, "/NonConcurrentJob",QDBusConnection::sessionBus(), this);
 
-    // create a DCOP stub for the non-concurrent cvs job
-    job = new CvsJob_stub(appId, "NonConcurrentJob");
+    QDBusConnection::sessionBus().connect(QString(), "/NonConcurrentJob", "org.kde.cervisia.cvsservice.cvsjob", "jobExited", this, SLOT(slotJobExited(bool,int)));
+    QDBusConnection::sessionBus().connect(QString(), "/NonConcurrentJob", "org.kde.cervisia.cvsservice.cvsjob", "receivedStdout", this, SLOT(slotReceivedOutput(QString)));
+    QDBusConnection::sessionBus().connect(QString(), "/NonConcurrentJob", "org.kde.cervisia.cvsservice.cvsjob", "receivedStderr", this, SLOT(slotReceivedOutput(QString)));
 
-    // establish connections to the signals of the cvs job
-    connectDCOPSignal(job->app(), job->obj(), "jobExited(bool, int)",
-                      "slotJobExited(bool, int)", true);
-    connectDCOPSignal(job->app(), job->obj(), "receivedStdout(QString)",
-                      "slotReceivedOutput(QString)", true);
-    connectDCOPSignal(job->app(), job->obj(), "receivedStderr(QString)",
-                      "slotReceivedOutput(QString)", true);
+    configChanged();
+
+    connect(CervisiaSettings::self(), SIGNAL(configChanged()),
+            this, SLOT(configChanged()));
 }
 
 
@@ -91,25 +85,37 @@ bool ProtocolView::startJob(bool isUpdateJob)
 }
 
 
-QPopupMenu* ProtocolView::createPopupMenu(const QPoint &pos)
+void ProtocolView::contextMenuEvent(QContextMenuEvent* event)
 {
-    QPopupMenu* menu = QTextEdit::createPopupMenu(pos);
+    QMenu *menu = QTextEdit::createStandardContextMenu();
 
-    int id = menu->insertItem(i18n("Clear"), this, SLOT( clear() ), 0, -1, 0);
+    QAction* clearAction = menu->addAction(i18n("Clear"), this, SLOT( clear() ));
 
-    if( length() == 0 )
-        menu->setItemEnabled(id, false);
+    if( document()->isEmpty() )
+        clearAction->setEnabled(false);
 
-    return menu;
+    menu->exec(event->globalPos());
+    delete menu;
 }
 
 
 void ProtocolView::cancelJob()
 {
+    kDebug(8050);
     job->cancel();
 }
 
 
+void ProtocolView::configChanged()
+{
+    conflictColor = CervisiaSettings::conflictColor();
+    localChangeColor = CervisiaSettings::localChangeColor();
+    remoteChangeColor = CervisiaSettings::remoteChangeColor();
+
+    setFont(CervisiaSettings::protocolFont());
+}
+
+
 void ProtocolView::slotReceivedOutput(QString buffer)
 {
     buf += buffer;
@@ -119,12 +125,13 @@ void ProtocolView::slotReceivedOutput(QString buffer)
 
 void ProtocolView::slotJobExited(bool normalExit, int exitStatus)
 {
+    kDebug(8050);
     QString msg;
 
     if( normalExit )
     {
         if( exitStatus )
-            msg = i18n("[Exited with status %1]\n").arg(exitStatus);
+            msg = i18n("[Exited with status %1]\n", exitStatus);
         else
             msg = i18n("[Finished]\n");
     }
@@ -142,16 +149,16 @@ void ProtocolView::slotJobExited(bool normalExit, int exitStatus)
 void ProtocolView::processOutput()
 {
     int pos;
-    while ( (pos = buf.find('\n')) != -1)
-	{
-	    QString line = buf.left(pos);
-	    if (!line.isEmpty())
-                {
-		    appendLine(line);
-                    emit receivedLine(line);
-                }
-	    buf = buf.right(buf.length()-pos-1);
-	}
+    while ( (pos = buf.indexOf('\n')) != -1)
+    {
+        QString line = buf.left(pos);
+        if (!line.isEmpty())
+        {
+            appendLine(line);
+            emit receivedLine(line);
+        }
+        buf = buf.right(buf.length()-pos-1);
+    }
 }
 
 
@@ -159,13 +166,13 @@ void ProtocolView::appendLine(const QString &line)
 {
     // Escape output line, so that html tags in commit
     // messages aren't interpreted
-    const QString escapedLine = QStyleSheet::escape(line);
+    const QString escapedLine = Qt::escape(line);
 
     // When we don't get the output from an update job then
     // just add it to the text edit.
     if( !m_isUpdateJob )
     {
-        append(escapedLine);
+        appendHtml(escapedLine);
         return;
     }
 
@@ -179,18 +186,25 @@ void ProtocolView::appendLine(const QString &line)
     else if (line.startsWith("P ") || line.startsWith("U "))
         color = remoteChangeColor;
 
-    append(color.isValid()
+    appendHtml(color.isValid()
            ? QString("<font color=\"%1\"><b>%2</b></font>").arg(color.name())
                                                            .arg(escapedLine)
            : escapedLine);
 }
 
 
+void ProtocolView::appendHtml(const QString& html)
+{
+    QTextCursor cursor(textCursor());
+    cursor.insertHtml(html);
+    cursor.insertBlock();
+    ensureCursorVisible();
+}
+
+
 #include "protocolview.moc"
 
 
 // Local Variables:
 // c-basic-offset: 4
 // End:
-
-
