@@ -37,6 +37,8 @@
 #include <KXmlGuiWindow>
 #include <KConfig>
 #include <KConfigGroup>
+#include <KComboBox>
+#include <KLineEdit>
 #include <KRun>
 #include <KIconDialog>
 #include <KMenu>
@@ -44,10 +46,8 @@
 #include <kdebug.h>
 
 #include <QBitmap>
-#include <QComboBox>
 #include <QFile>
 #include <QLabel>
-#include <QLineEdit>
 #include <QPushButton>
 #include <QRegExp>
 #include <QToolButton>
@@ -103,9 +103,13 @@ bool KateExternalTool::checkExec()
       // !!! Sergey A. Sukiyazov <corwin@micom.don.ru> !!!
       // Environment PATH may contain filenames in 8bit locale cpecified
       // encoding (Like a filenames).
-      QString path = QFile::decodeName(::getenv("PATH"));
-      QStringList dirs = path.split(':', QString::SkipEmptyParts);
-      QStringList::Iterator it(dirs.begin());
+      const QString path = QFile::decodeName(qgetenv("PATH"));
+#ifdef Q_WS_WIN
+      const QStringList dirs = path.split(';', QString::SkipEmptyParts);
+#else
+      const QStringList dirs = path.split(':', QString::SkipEmptyParts);
+#endif
+      QStringList::ConstIterator it(dirs.begin());
       bool match = false;
       for (; it != dirs.end(); ++it)
       {
@@ -159,10 +163,10 @@ void KateExternalToolsCommand::reload ()
 
   KConfig _config( "externaltools", KConfig::NoGlobals, "appdata" );
   KConfigGroup config(&_config, "Global");
-  QStringList tools = config.readEntry("tools", QStringList());
+  const QStringList tools = config.readEntry("tools", QStringList());
 
 
-  for( QStringList::Iterator it = tools.begin(); it != tools.end(); ++it )
+  for( QStringList::const_iterator it = tools.begin(); it != tools.end(); ++it )
   {
     if ( *it == "---" )
       continue;
@@ -341,6 +345,11 @@ KateExternalToolsMenuAction::KateExternalToolsMenuAction( const QString &text,
   reload();
 }
 
+KateExternalToolsMenuAction::~KateExternalToolsMenuAction()
+{
+  //kDebug() << "deleted KateExternalToolsMenuAction";
+}
+
 void KateExternalToolsMenuAction::reload()
 {
   m_actionCollection->clear ();
@@ -382,7 +391,7 @@ void KateExternalToolsMenuAction::reload()
     config.writeEntry( "version", gver );
   }
 
-  for( QStringList::Iterator it = tools.begin(); it != tools.end(); ++it )
+  for( QStringList::const_iterator it = tools.constBegin(); it != tools.constEnd(); ++it )
   {
     if ( *it == "---" )
     {
@@ -489,7 +498,7 @@ KateExternalToolServiceEditor::KateExternalToolServiceEditor( KateExternalTool *
 
   QLabel *l;
 
-  leName = new QLineEdit( w );
+  leName = new KLineEdit( w );
   lo->addWidget( leName, 1, 2 );
   l = new QLabel( w );
   l->setBuddy( leName );
@@ -531,7 +540,7 @@ KateExternalToolServiceEditor::KateExternalToolServiceEditor( KateExternalTool *
                             "<li><code>%text</code> - the text of the current document.</li></ul>" ) );
 
 
-  leExecutable = new QLineEdit( w );
+  leExecutable = new KLineEdit( w );
   lo->addWidget( leExecutable, 3, 2, 1, 2 );
   l = new QLabel( w );
   l->setBuddy( leExecutable );
@@ -544,7 +553,7 @@ KateExternalToolServiceEditor::KateExternalToolServiceEditor( KateExternalTool *
                                "should be displayed; if not set, the first word of <em>command</em> "
                                "will be used.") );
 
-  leMimetypes = new QLineEdit( w );
+  leMimetypes = new KLineEdit( w );
   lo->addWidget( leMimetypes, 4, 2 );
   l = new QLabel( w );
   l->setBuddy( leMimetypes );
@@ -564,7 +573,7 @@ KateExternalToolServiceEditor::KateExternalToolServiceEditor( KateExternalTool *
   btnMTW->setWhatsThis(i18n(
                          "Click for a dialog that can help you creating a list of mimetypes.") );
 
-  cmbSave = new QComboBox(w);
+  cmbSave = new KComboBox(w);
   lo->addWidget( cmbSave, 5, 2, 1, 2 );
   l = new QLabel( w );
   l->setBuddy( cmbSave );
@@ -581,7 +590,7 @@ KateExternalToolServiceEditor::KateExternalToolServiceEditor( KateExternalTool *
                           "an application like, for example, an FTP client.") );
 
 
-  leCmdLine = new QLineEdit( w );
+  leCmdLine = new KLineEdit( w );
   lo->addWidget( leCmdLine, 6, 2, 1, 2 );
   l = new QLabel( i18n("&Command line name:"), w );
   l->setBuddy( leCmdLine );
@@ -620,53 +629,23 @@ void KateExternalToolServiceEditor::showMTDlg()
 //END KateExternalToolServiceEditor
 
 //BEGIN KateExternalToolsConfigWidget
-KateExternalToolsConfigWidget::KateExternalToolsConfigWidget( QWidget *parent, const char* )
-    : KTextEditor::ConfigPage( parent ),
-    m_changed( false )
+KateExternalToolsConfigWidget::KateExternalToolsConfigWidget( QWidget *parent, const char* name)
+    : Kate::PluginConfigPage( parent, name )
+    , m_changed( false )
 {
-  QGridLayout *lo = new QGridLayout( this );
-  lo->setMargin( 0 );
-  lo->setSpacing( KDialog::spacingHint() );
+  setupUi(this);
 
-  lbTools = new KListWidget( this );
-  lo->addWidget( lbTools, 1, 0, 4, 4 );
-  connect( lbTools, SIGNAL(selectionChanged()), this, SLOT(slotSelectionChanged()) );
+  btnMoveUp->setIcon(KIcon("go-up"));
+  btnMoveDown->setIcon(KIcon("go-down"));
 
-  btnNew = new QPushButton( i18n("&New..."), this );
-  lo->addWidget( btnNew, 5, 0 );
+  connect( lbTools, SIGNAL(itemSelectionChanged()), this, SLOT(slotSelectionChanged()) );
+  connect( lbTools, SIGNAL( itemDoubleClicked ( QListWidgetItem * ) ), this, SLOT( slotEdit() ) );
   connect( btnNew, SIGNAL(clicked()), this, SLOT(slotNew()) );
-
-  btnRemove = new QPushButton( i18n("&Remove"), this );
-  lo->addWidget( btnRemove, 5, 2 );
   connect( btnRemove, SIGNAL(clicked()), this, SLOT(slotRemove()) );
-
-  btnEdit = new QPushButton( i18n("&Edit..."), this );
-  lo->addWidget( btnEdit, 5, 1 );
   connect( btnEdit, SIGNAL(clicked()), this, SLOT(slotEdit()) );
-
-  QPushButton *b = new QPushButton( i18n("Insert &Separator"), this );
-  lo->addWidget( b, 5, 3 );
-  connect( b, SIGNAL(clicked()), this, SLOT(slotInsertSeparator()) );
-
-  btnMoveUp = new QPushButton( KIcon("go-up"), "", this );
-  lo->addWidget( btnMoveUp, 2, 4 );
+  connect( btnSeparator, SIGNAL(clicked()), this, SLOT(slotInsertSeparator()) );
   connect( btnMoveUp, SIGNAL(clicked()), this, SLOT(slotMoveUp()) );
-
-  btnMoveDwn = new QPushButton( KIcon("go-down"), "", this );
-  lo->addWidget( btnMoveDwn, 3, 4 );
-  connect( btnMoveDwn, SIGNAL(clicked()), this, SLOT(slotMoveDown()) );
-
-  connect( lbTools, SIGNAL( doubleClicked ( QListWidgetItem * ) ), this, SLOT( slotEdit() ) );
-
-  lo->setRowStretch( 1, 1 );
-  lo->setRowStretch( 4, 1 );
-  lo->setColumnStretch( 0, 1 );
-  lo->setColumnStretch( 1, 1 );
-  lo->setColumnStretch( 2, 1 );
-
-
-  lbTools->setWhatsThis(i18n(
-                          "This list shows all the configured tools, represented by their menu text.") );
+  connect( btnMoveDown, SIGNAL(clicked()), this, SLOT(slotMoveDown()) );
 
   config = new KConfig( "externaltools", KConfig::NoGlobals, "appdata" );
   reset();
@@ -684,9 +663,9 @@ void KateExternalToolsConfigWidget::reset()
   lbTools->clear();
 
   // load the files from a KConfig
-  QStringList tools = config->group("Global").readEntry("tools", QStringList());
+  const QStringList tools = config->group("Global").readEntry("tools", QStringList());
 
-  for( QStringList::Iterator it = tools.begin(); it != tools.end(); ++it )
+  for( QStringList::const_iterator it = tools.begin(); it != tools.end(); ++it )
   {
     if ( *it == "---" )
     {
@@ -793,7 +772,7 @@ void KateExternalToolsConfigWidget::slotSelectionChanged()
   btnEdit->setEnabled( hs && dynamic_cast<ToolItem*>(lbTools->currentItem()) );
   btnRemove->setEnabled( hs );
   btnMoveUp->setEnabled( ( lbTools->currentRow() > 0 ) && hs );
-  btnMoveDwn->setEnabled( ( lbTools->currentRow() < (int)lbTools->count() - 1 ) && hs );
+  btnMoveDown->setEnabled( ( lbTools->currentRow() < (int)lbTools->count() - 1 ) && hs );
 }
 
 void KateExternalToolsConfigWidget::slotNew()
