@@ -23,54 +23,45 @@
 #include "katefileselector.h"
 #include "katefileselector.moc"
 
-#include <QToolButton>
-#include <khbox.h>
-#include <kvbox.h>
+#include <QApplication>
+#include <QCheckBox>
+#include <QDir>
+#include <QGroupBox>
+#include <QKeyEvent>
 #include <QLabel>
 #include <QLineEdit>
-#include <QApplication>
 #include <QListWidget>
-#include <QSpinBox>
-#include <QGroupBox>
-#include <QCheckBox>
 #include <QRegExp>
-#include <QDir>
-//Added by qt3to4:
-#include <QFocusEvent>
-#include <QEvent>
-#include <QShowEvent>
+#include <QSpinBox>
+#include <QToolButton>
 #include <QVBoxLayout>
 
+#include <kate/mainwindow.h>
+#include <ktexteditor/view.h>
+
+#include <kaboutdata.h>
 #include <kactioncollection.h>
 #include <kactionmenu.h>
 #include <kactionselector.h>
 #include <kbookmarkhandler.h>
-#include <kconfig.h>
-#include <kcombobox.h>
+#include <kconfiggroup.h>
 #include <kdebug.h>
 #include <kdialog.h>
 #include <kdiroperator.h>
 #include <kfileitem.h>
-#include <kgenericfactory.h>
-#include <kglobal.h>
-#include <kglobalsettings.h>
-#include <kiconloader.h>
-#include <klocale.h>
-#include <kmenu.h>
-#include <kmessagebox.h>
-#include <kprotocolinfo.h>
-#include <kurlcombobox.h>
-#include <kurlcompletion.h>
-#include <kate/mainwindow.h>
-#include <ktexteditor/view.h>
-#include <kconfiggroup.h>
+#include <khbox.h>
 #include <khistorycombobox.h>
 #include <kdeversion.h>
+#include <kpluginfactory.h>
+#include <ktoolbar.h>
+#include <kurlcombobox.h>
+#include <kurlcompletion.h>
 //END Includes
 
-K_EXPORT_COMPONENT_FACTORY( katefilebrowserplugin, KGenericFactory<KateFileSelectorPlugin>( "katefilebrowserplugin" ) )
+K_PLUGIN_FACTORY(KateFileSelectorFactory, registerPlugin<KateFileSelectorPlugin>();)
+K_EXPORT_PLUGIN(KateFileSelectorFactory(KAboutData("katefilebrowserplugin","katefilebrowserplugin",ki18n("Filesystem Browser"), "0.1", ki18n("Browse through the filesystem"), KAboutData::License_LGPL_V2)) )
 
-KateFileSelectorPlugin::KateFileSelectorPlugin( QObject* parent, const QStringList&):
+KateFileSelectorPlugin::KateFileSelectorPlugin( QObject* parent, const QList<QVariant>&):
     Kate::Plugin ( (Kate::Application*)parent )
 {}
 
@@ -111,8 +102,8 @@ uint KateFileSelectorPlugin::configPages() const
 }
 
 Kate::PluginConfigPage *KateFileSelectorPlugin::configPage (uint number, QWidget *parent, const char *name)
-{	
-  if (number != 0) 
+{
+  if (number != 0)
     return 0;
   return new KFSConfigPage(parent, name, m_fileSelector);
 }
@@ -136,24 +127,7 @@ KIcon KateFileSelectorPlugin::configPageIcon (uint number) const
   return KIcon("document-open");
 }
 
-//BEGIN Toolbar
-// from kfiledialog.cpp - avoid qt warning in STDERR (~/.xsessionerrors)
-static void silenceQToolBar(QtMsgType, const char *)
-{}
-
-// helper classes to be able to have a toolbar without move handle
-KateFileSelectorToolBar::KateFileSelectorToolBar(QWidget *parent)
-    : KToolBar( parent, "Kate FileSelector Toolbar", true )
-{
-  setMinimumWidth(10);
-}
-
-KateFileSelectorToolBar::~KateFileSelectorToolBar()
-{}
-//END
-
 //BEGIN Constructor/destructor
-
 KateFileSelector::KateFileSelector( Kate::MainWindow *mainWindow,
                                       QWidget * parent, const char * name )
     : KVBox (parent),
@@ -163,11 +137,8 @@ KateFileSelector::KateFileSelector( Kate::MainWindow *mainWindow,
   setObjectName(name);
   mActionCollection = new KActionCollection( this );
 
-  QtMsgHandler oldHandler = qInstallMsgHandler( silenceQToolBar );
-
-  toolbar = new KateFileSelectorToolBar(this);
+  toolbar = new KToolBar(this);
   toolbar->setMovable(false);
-  qInstallMsgHandler( oldHandler );
 
   cmbPath = new KUrlComboBox( KUrlComboBox::Directories, true, this);
   cmbPath->setSizePolicy( QSizePolicy( QSizePolicy::Expanding, QSizePolicy::Fixed ));
@@ -178,16 +149,14 @@ KateFileSelector::KateFileSelector( Kate::MainWindow *mainWindow,
 // FIXME
 //  cmbPath->listBox()->installEventFilter( this );
 
-  dir = new KDirOperator(KUrl(), this);
-  dir->installEventFilter( this );
-  dir->setView(KFile::/* Simple */Detail);
-  dir->view()->setSelectionMode(QAbstractItemView::ExtendedSelection);
-  if (KGlobalSettings::singleClick())
-    dir->setOnlyDoubleClickSelectsFiles(false);
-  connect ( dir, SIGNAL( viewChanged(QAbstractItemView *) ),
+  m_dirOperator = new KDirOperator(KUrl(), this);
+  m_dirOperator->installEventFilter( this );
+  m_dirOperator->setView(KFile::/* Simple */Detail);
+  m_dirOperator->view()->setSelectionMode(QAbstractItemView::ExtendedSelection);
+  connect ( m_dirOperator, SIGNAL( viewChanged(QAbstractItemView *) ),
            this, SLOT( selectorViewChanged(QAbstractItemView *) ) );
-  setStretchFactor(dir, 2);
-  dir->setSizePolicy (QSizePolicy (QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding));
+  setStretchFactor(m_dirOperator, 2);
+  m_dirOperator->setSizePolicy (QSizePolicy (QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding));
 
   // bookmarks action!
   KActionMenu *acmBookmarks = new KActionMenu( KIcon("bookmarks"), i18n("Bookmarks"), this );
@@ -202,14 +171,14 @@ KateFileSelector::KateFileSelector( Kate::MainWindow *mainWindow,
   filter = new KHistoryComboBox( true, filterBox);
   filter->setSizePolicy( QSizePolicy( QSizePolicy::Expanding, QSizePolicy::Fixed ));
   filterBox->setStretchFactor(filter, 2);
-  connect( btnFilter, SIGNAL( clicked() ), this, SLOT( btnFilterClick() ) );
+  connect( btnFilter, SIGNAL( clicked() ), this, SLOT( filterButtonClicked() ) );
 
   connect( filter, SIGNAL( activated(const QString&) ),
            SLOT( slotFilterChange(const QString&) ) );
   connect( filter, SIGNAL( returnPressed(const QString&) ),
            filter, SLOT( addToHistory(const QString&) ) );
 
-  // kaction for the dir sync method
+  // kaction for the m_dirOperator sync method
   acSyncDir = mActionCollection->addAction( "sync_dir" );
   acSyncDir->setIcon( KIcon("curfiledir") );
   acSyncDir->setText( i18n("Current Document Folder") );
@@ -222,13 +191,10 @@ KateFileSelector::KateFileSelector( Kate::MainWindow *mainWindow,
            this, SLOT( cmbPathActivated( const KUrl& ) ));
   connect( cmbPath, SIGNAL( returnPressed( const QString&  )),
            this, SLOT( cmbPathReturnPressed( const QString& ) ));
-  connect(dir, SIGNAL(urlEntered(const KUrl&)),
+  connect(m_dirOperator, SIGNAL(urlEntered(const KUrl&)),
           this, SLOT(dirUrlEntered(const KUrl&)) );
 
-  connect(dir, SIGNAL(finishedLoading()),
-          this, SLOT(dirFinishedLoading()) );
-
-  // enable dir sync button if current doc has a valid URL
+  // enable m_dirOperator sync button if current doc has a valid URL
   connect ( mainwin, SIGNAL( viewChanged() ),
             this, SLOT( kateViewChanged() ) );
 
@@ -249,7 +215,7 @@ KateFileSelector::KateFileSelector( Kate::MainWindow *mainWindow,
   btnFilter->setWhatsThis(        i18n("<p>This button clears the name filter when toggled off, or "
                                        "reapplies the last filter used when toggled on.</p>") );
 
-  connect(dir, SIGNAL(fileSelected(const KFileItem&)), this, SLOT(fileSelected(const KFileItem&)));
+  connect(m_dirOperator, SIGNAL(fileSelected(const KFileItem&)), this, SLOT(fileSelected(const KFileItem&)));
 
   readConfig();
 
@@ -271,8 +237,8 @@ KateFileSelector::~KateFileSelector()
 void KateFileSelector::readConfig()
 {
 
-//   dir->setView( KFile::Default );
-//   dir->view()->setSelectionMode(QAbstractItemView::ExtendedSelection);
+//   m_dirOperator->setView( KFile::Default );
+//   m_dirOperator->view()->setSelectionMode(QAbstractItemView::ExtendedSelection);
 
   // set up the toolbar
   KConfigGroup fileselectorConfigGroup(KGlobal::config(), "fileselector");
@@ -290,11 +256,11 @@ void ::KateFileSelector::readSessionConfig(KConfigBase *config, const QString &
 {
 
   KConfigGroup cgView(config, name + ":view");
-  dir->setViewConfig(cgView );
+  m_dirOperator->setViewConfig(cgView );
 
   KConfigGroup cgDir(config, name + ":dir");
-  dir->readConfig(cgDir);
-  dir->setView(KFile::Default);
+  m_dirOperator->readConfig(cgDir);
+  m_dirOperator->setView(KFile::Default);
 
   KConfigGroup cg (config, name );
   cmbPath->setUrls( cg.readPathEntry( "dir history", QStringList() ) );
@@ -329,16 +295,16 @@ void ::KateFileSelector::setupToolbar( QStringList actions )
   {
     // reasonable collection for default toolbar
     actions << "up" << "back" << "forward" << "home" <<
-    "short view" << "detailed view" <<
+    "short view" << "detailed view" << "tree view" <<
     "bookmarks" << "sync_dir";
   }
   QAction *ac;
-  for ( QStringList::Iterator it = actions.begin(); it != actions.end(); ++it )
+  for ( QStringList::ConstIterator it = actions.constBegin(); it != actions.constEnd(); ++it )
   {
     if ( *it == "bookmarks" || *it == "sync_dir" )
       ac = mActionCollection->action( (*it).toLatin1().constData() );
     else
-      ac = dir->actionCollection()->action( (*it).toLatin1().constData() );
+      ac = m_dirOperator->actionCollection()->action( (*it).toLatin1().constData() );
     if ( ac )
       toolbar->addAction( ac );
   }
@@ -357,7 +323,7 @@ void KateFileSelector::writeConfig()
 void KateFileSelector::writeSessionConfig(KConfigBase *config, const QString & name)
 {
   KConfigGroup cgDir(config, name + ":dir");
-  dir->writeConfig(cgDir);
+  m_dirOperator->writeConfig(cgDir);
 
   KConfigGroup cg = KConfigGroup( config, name );
   QStringList l;
@@ -373,8 +339,8 @@ void KateFileSelector::writeSessionConfig(KConfigBase *config, const QString & n
 
 void ::KateFileSelector::setView(KFile::FileView view)
 {
-  dir->setView(view);
-  dir->view()->setSelectionMode(QAbstractItemView::ExtendedSelection);
+  m_dirOperator->setView(view);
+  m_dirOperator->view()->setSelectionMode(QAbstractItemView::ExtendedSelection);
 }
 
 //END Public Methods
@@ -384,25 +350,26 @@ void ::KateFileSelector::setView(KFile::FileView view)
 void ::KateFileSelector::slotFilterChange( const QString & nf )
 {
   QString f = nf.trimmed();
-  bool empty = f.isEmpty() || f == "*";
+  const bool empty = f.isEmpty() || f == "*";
+
   if ( empty )
   {
-    dir->clearFilter();
+    m_dirOperator->clearFilter();
     filter->lineEdit()->setText( QString() );
-    btnFilter->setToolTip(
-      i18n("Apply last filter (\"%1\")", lastFilter )) ;
+    btnFilter->setToolTip( i18n("Apply last filter (\"%1\")", lastFilter) ) ;
   }
   else
   {
-    dir->setNameFilter( f );
+    m_dirOperator->setNameFilter( f );
     lastFilter = f;
     btnFilter->setToolTip( i18n("Clear filter") );
   }
+
   btnFilter->setChecked( !empty );
-  dir->updateDir();
+  m_dirOperator->updateDir();
+
   // this will be never true after the filter has been used;)
   btnFilter->setEnabled( !( empty && lastFilter.isEmpty() ) );
-
 }
 
 bool kateFileSelectorIsReadable ( const KUrl& url )
@@ -410,7 +377,7 @@ bool kateFileSelectorIsReadable ( const KUrl& url )
   if ( !url.isLocalFile() )
     return true; // what else can we say?
 
-  QDir dir (url.path());
+  QDir dir(url.path());
   return dir.exists ();
 }
 
@@ -432,7 +399,7 @@ void ::KateFileSelector::setDir( KUrl u )
   if ( !kateFileSelectorIsReadable (newurl) )
     newurl.setPath( QDir::homePath() );
 
-  dir->setUrl(newurl, true);
+  m_dirOperator->setUrl(newurl, true);
 }
 
 //END Public Slots
@@ -446,14 +413,14 @@ void ::KateFileSelector::fileSelected(const KFileItem & /*file*/)
 
 void ::KateFileSelector::openSelectedFiles()
 {
-  const KFileItemList list = dir->selectedItems();
+  const KFileItemList list = m_dirOperator->selectedItems();
 
   foreach (const KFileItem& item, list)
   {
     mainwin->openUrl(item.url());
   }
 
-  dir->view()->selectionModel()->clear();
+  m_dirOperator->view()->selectionModel()->clear();
 }
 
 
@@ -466,26 +433,27 @@ void ::KateFileSelector::cmbPathActivated( const KUrl& u )
 
 void ::KateFileSelector::cmbPathReturnPressed( const QString& u )
 {
-  KUrl typedURL( u );
-  if ( typedURL.hasPass() )
-    typedURL.setPass( QString() );
+  // construct so that relative urls are ok
+  KUrl typedURL( m_dirOperator->url(), u );
 
+  //m_dirOperator->setFocus(); // is it really useful to set focus here?
+  m_dirOperator->setUrl( typedURL, true );
+  qobject_cast<KUrlCompletion *>( cmbPath->completionObject() )->setDir( typedURL.pathOrUrl() );
+
+  // strip password (noop if there's none)
+  typedURL.setPass( QString() );
   QStringList urls = cmbPath->urls();
   urls.removeAll( typedURL.url() );
   urls.prepend( typedURL.url() );
   cmbPath->setUrls( urls, KUrlComboBox::RemoveBottom );
-  dir->setFocus();
-  dir->setUrl( KUrl(u), true );
 }
 
 void ::KateFileSelector::dirUrlEntered( const KUrl& u )
 {
   cmbPath->setUrl( u );
+  qobject_cast<KUrlCompletion *>( cmbPath->completionObject() )->setDir( u.pathOrUrl() );
 }
 
-void ::KateFileSelector::dirFinishedLoading()
-{}
-
 
 /*
    When the button in the filter box toggles:
@@ -494,7 +462,7 @@ void ::KateFileSelector::dirFinishedLoading()
    If on:
    Set last filter.
 */
-void ::KateFileSelector::btnFilterClick()
+void ::KateFileSelector::filterButtonClicked()
 {
   if ( !btnFilter->isChecked() )
   {
@@ -562,7 +530,7 @@ KUrl KateFileSelector::activeDocumentUrl()
 
 void KateFileSelector::focusInEvent( QFocusEvent * )
 {
-  dir->setFocus();
+  m_dirOperator->setFocus();
 }
 
 void KateFileSelector::showEvent( QShowEvent * )
@@ -654,11 +622,11 @@ KFSConfigPage::KFSConfigPage( QWidget *parent, const char *, KateFileSelector *k
   acSel = new KActionSelector( gbToolbar );
   acSel->setAvailableLabel( i18n("A&vailable actions:") );
   acSel->setSelectedLabel( i18n("S&elected actions:") );
-  
+
   QVBoxLayout *vbox = new QVBoxLayout;
   vbox->addWidget(acSel);
   gbToolbar->setLayout(vbox);
-  
+
   lo->addWidget( gbToolbar );
   connect( acSel, SIGNAL( added( QListWidgetItem * ) ), this, SLOT( slotMyChanged() ) );
   connect( acSel, SIGNAL( removed( QListWidgetItem * ) ), this, SLOT( slotMyChanged() ) );
@@ -669,12 +637,12 @@ KFSConfigPage::KFSConfigPage( QWidget *parent, const char *, KateFileSelector *k
   QGroupBox *gbSync = new QGroupBox(i18n("Auto Synchronization"), this );
   cbSyncActive = new QCheckBox( i18n("When a docu&ment becomes active"));
   cbSyncShow = new QCheckBox( i18n("When the file selector becomes visible"));
-  
+
   vbox = new QVBoxLayout;
   vbox->addWidget(cbSyncActive);
   vbox->addWidget(cbSyncShow);
   gbSync->setLayout(vbox);
-  
+
   lo->addWidget( gbSync );
   connect( cbSyncActive, SIGNAL( toggled( bool ) ), this, SLOT( slotMyChanged() ) );
   connect( cbSyncShow, SIGNAL( toggled( bool ) ), this, SLOT( slotMyChanged() ) );
@@ -698,12 +666,12 @@ KFSConfigPage::KFSConfigPage( QWidget *parent, const char *, KateFileSelector *k
   QGroupBox *gbSession = new QGroupBox(i18n("Session"), this );
   cbSesLocation = new QCheckBox( i18n("Restore loca&tion"));
   cbSesFilter = new QCheckBox( i18n("Restore last f&ilter"));
-  
+
   vbox = new QVBoxLayout;
   vbox->addWidget(cbSesLocation);
   vbox->addWidget(cbSesFilter);
   gbSession->setLayout(vbox);
-  
+
   lo->addWidget( gbSession );
   connect( cbSesLocation, SIGNAL( toggled( bool ) ), this, SLOT( slotMyChanged() ) );
   connect( cbSesFilter, SIGNAL( toggled( bool ) ), this, SLOT( slotMyChanged() ) );
@@ -808,7 +776,7 @@ void KFSConfigPage::init()
   QStringList l = config.readEntry( "toolbar actions", QStringList() );
   if ( l.isEmpty() ) // default toolbar
     l << "up" << "back" << "forward" << "home" <<
-    "short view" << "detailed view" <<
+    "short view" << "detailed view" << "tree view" <<
     "bookmarks" << "sync_dir";
 
   // actions from diroperator + two of our own
@@ -817,6 +785,7 @@ void KFSConfigPage::init()
   "reload" << "mkdir" << "delete" <<
   "short view" << "detailed view" /*<< "view menu" <<
                   "show hidden" << "properties"*/ <<
+  "tree view" << "detailed tree view" <<
   "bookmarks" << "sync_dir";
   QRegExp re("&(?=[^&])");
   QAction *ac;
