@@ -47,10 +47,10 @@ class Processor
                                          Package::List &packages ) = 0;
     virtual KBB::Error parseBugDetails( const QByteArray &, BugDetails & ) = 0;
 
-    virtual void setPackageListQuery( KURL & ) = 0;
-    virtual void setBugListQuery( KURL &, const Package &,
+    virtual void setPackageListQuery( KUrl & ) = 0;
+    virtual void setBugListQuery( KUrl &, const Package &,
                                   const QString &component ) = 0;
-    virtual void setBugDetailsQuery( KURL &, const Bug & ) = 0;
+    virtual void setBugDetailsQuery( KUrl &, const Bug & ) = 0;
 
   private:
     BugServer *mServer;
