@@ -15,16 +15,18 @@
  ***************************************************************************/
 
 #include "kbbmainwindow.h"
-
+#include <kselectaction.h>
+#include <ktoggleaction.h>
+#include <kactionmenu.h>
 #include <qlabel.h>
 #include <qlayout.h>
-#include <qmultilineedit.h>
-#include <qprogressbar.h>
 #include <qpushbutton.h>
-#include <qtextview.h>
-#include <qwidgetstack.h>
+#include <QTextEdit>
+#include <QVBoxLayout>
+#include <QBoxLayout>
 
 #include <kaction.h>
+#include <kactioncollection.h>
 #include <kbookmarkmenu.h>
 #include <kcombobox.h>
 #include <kconfig.h>
@@ -32,15 +34,15 @@
 #include <kdialog.h>
 #include <kinputdialog.h>
 #include <klineedit.h>
-#include <klistview.h>
 #include <klocale.h>
 #include <kmenubar.h>
 #include <kmessagebox.h>
 #include <kstatusbar.h>
-#include <kstdaction.h>
-#include <kstdguiitem.h>
+#include <kstandardaction.h>
+#include <kstandardguiitem.h>
 #include <kedittoolbar.h>
-
+#include <QProgressBar>
+#include <kicon.h>
 
 #include "bugcommand.h"
 #include "bugserver.h"
@@ -58,20 +60,23 @@
 
 using namespace KBugBusterMainWindow;
 
-class TextViewer : public KDialogBase
+class TextViewer : public KDialog
 {
   public:
     TextViewer( const QString &title, QWidget *parent = 0 )
-      : KDialogBase( Plain, title, Ok, Ok, parent, 0,
-                     false )
+      : KDialog( parent)
     {
-      QFrame *topFrame = plainPage();
+        setCaption( title );
+        setButtons( Ok );
+        setDefaultButton( Ok );
+        setModal( false );
+      QFrame *topFrame = new QFrame( this );
+      setMainWidget( topFrame );
 
       QBoxLayout *topLayout = new QVBoxLayout( topFrame );
 
       mTextView = new QTextEdit( topFrame );
       mTextView->setReadOnly( true );
-      mTextView->setTextFormat( PlainText );
       topLayout->addWidget( mTextView );
 
       resize( 600, 400 );
@@ -79,7 +84,7 @@ class TextViewer : public KDialogBase
 
     void setText( const QString &text )
     {
-      mTextView->setText( text );
+      mTextView->setPlainText( text );
     }
 
   private:
@@ -88,13 +93,14 @@ class TextViewer : public KDialogBase
 
 KBookmarkManager* KBBBookmarkManager::s_bookmarkManager;
 
-KBBMainWindow::KBBMainWindow( const QCString &initialPackage,
-                              const QCString &initialComponent,
-                              const QCString &initialBug,
+KBBMainWindow::KBBMainWindow( const QByteArray &initialPackage,
+                              const QByteArray &initialComponent,
+                              const QByteArray &initialBug,
                               QWidget * , const char * name )
-  : KMainWindow( 0, name ), mPreferencesDialog( 0 ), mResponseViewer( 0 ),
+  : KXmlGuiWindow( 0 ), mPreferencesDialog( 0 ), mResponseViewer( 0 ),
     mBugSourceViewer( 0 ), mPackageSelectDialog( 0 )
 {
+    setObjectName( name );
     BugSystem::self()->setCurrentServer( KBBPrefs::instance()->mCurrentServer );
 
     m_statusLabel = new QLabel( i18n( "Welcome to <b>KBugBuster</b>." ), statusBar() );
@@ -108,8 +114,9 @@ KBBMainWindow::KBBMainWindow( const QCString &initialPackage,
 
     initActions();
 
-    m_progressBar = new QProgressBar( 100, statusBar() );
-    m_progressBar->setCenterIndicator( true );
+    m_progressBar = new QProgressBar( statusBar() );
+    m_progressBar->setMaximum(100);
+    m_progressBar->setAlignment( Qt::AlignHCenter );
     m_progressBar->setMinimumWidth( 150 );
     m_progressBar->setMaximumHeight( statusBar()->fontMetrics().height() + 6 );
     statusBar()->addWidget( m_progressBar );
@@ -133,7 +140,7 @@ KBBMainWindow::KBBMainWindow( const QCString &initialPackage,
 
 KBBMainWindow::~KBBMainWindow()
 {
-//    kdDebug() << "KBBMainWindow::~KBBMainWindow()" << endl;
+//    kDebug() << "KBBMainWindow::~KBBMainWindow()";
     delete m_pBookmarkMenu;
 
     m_mainWidget->writeConfig();
@@ -144,115 +151,146 @@ KBBMainWindow::~KBBMainWindow()
 void KBBMainWindow::initActions()
 {
     // Prepare and create XML GUI
-    fileQuit          = KStdAction::quit( this,
+    fileQuit          = KStandardAction::quit( this,
                         SLOT( close() ), actionCollection() );
     fileQuit->setToolTip( i18n( "Quit KBugBuster" ) );
 
-    new KAction( i18n("See &Pending Changes"), "contents", 0, this, SLOT( slotListChanges() ),
-                 actionCollection(), "file_seechanges" );
-    new KAction( i18n("&Submit Changes"), "mail_send", 0, this, SLOT( slotSubmit() ),
-                 actionCollection(), "file_submit" );
+    KAction *action = actionCollection()->addAction( "file_seechanges" );
+    action->setIcon( KIcon("document-preview") );
+    action->setText( i18n("See &Pending Changes") );
+    connect(action, SIGNAL(triggered(bool)), SLOT( slotListChanges() ));
+    action = actionCollection()->addAction( "file_submit" );
+    action->setIcon( KIcon("mail-send") );
+    action->setText( i18n("&Submit Changes") );
+    connect(action, SIGNAL(triggered(bool)), SLOT( slotSubmit() ));
 
-    reloadpacklist = new KAction( i18n("Reload &Product List"), "reload", CTRL+Qt::Key_F5, m_mainWidget, SLOT( slotReloadPackageList() ),
-                 actionCollection(), "reload_packagelist" );
-    reloadpack= new KAction( i18n("Reload Bug &List (for current product)"), "reload", Qt::Key_F5, m_mainWidget, SLOT( slotReloadPackage() ),
-                 actionCollection(), "reload_package" );
-    reloadbug = new KAction( i18n("Reload Bug &Details (for current bug)"), "reload", SHIFT+Qt::Key_F5, m_mainWidget, SLOT( slotReloadBug() ),
-                 actionCollection(), "reload_bug" );
-    loadMyBugs = new KAction( i18n( "Load &My Bugs List" ), 0, m_mainWidget, SLOT( slotLoadMyBugs() ),
-                 actionCollection(), "load_my_bugs" );
-    reloadall = new KAction( i18n("Load All Bug Details (for current product)"), Qt::Key_F6, m_mainWidget, SLOT( slotRetrieveAllBugDetails() ), actionCollection(), "load_allbugs" );
-    new KAction( i18n("Extract &Attachments"), "filesave", Qt::Key_F4, m_mainWidget, SLOT( slotExtractAttachments() ),
-                 actionCollection(), "extract_attachments" );
+    reloadpacklist = actionCollection()->addAction( "reload_packagelist" );
+    reloadpacklist->setIcon( KIcon("view-refresh") );
+    reloadpacklist->setText( i18n("Reload &Product List") );
+    connect(reloadpacklist, SIGNAL(triggered(bool)), m_mainWidget, SLOT( slotReloadPackageList() ));
+    reloadpacklist->setShortcut(QKeySequence(Qt::CTRL+Qt::Key_F5));
+    reloadpack = actionCollection()->addAction( "reload_package" );
+    reloadpack->setIcon( KIcon("view-refresh") );
+    reloadpack->setText( i18n("Reload Bug &List (for current product)") );
+    connect(reloadpack, SIGNAL(triggered(bool)), m_mainWidget, SLOT( slotReloadPackage() ));
+    reloadpack->setShortcut(QKeySequence(Qt::Key_F5));
+    reloadbug = actionCollection()->addAction( "reload_bug" );
+    reloadbug->setIcon( KIcon("view-refresh") );
+    reloadbug->setText( i18n("Reload Bug &Details (for current bug)") );
+    connect(reloadbug, SIGNAL(triggered(bool)), m_mainWidget, SLOT( slotReloadBug() ));
+    reloadbug->setShortcut(QKeySequence(Qt::SHIFT+Qt::Key_F5));
+    loadMyBugs = actionCollection()->addAction( "load_my_bugs" );
+    loadMyBugs->setText( i18n( "Load &My Bugs List" ) );
+    connect(loadMyBugs, SIGNAL(triggered(bool) ), m_mainWidget, SLOT( slotLoadMyBugs() ));
+    reloadall = actionCollection()->addAction( "load_allbugs" );
+    reloadall->setText( i18n("Load All Bug Details (for current product)") );
+    connect(reloadall, SIGNAL(triggered(bool) ), m_mainWidget, SLOT( slotRetrieveAllBugDetails() ));
+    reloadall->setShortcut(QKeySequence(Qt::Key_F6));
+    action = actionCollection()->addAction( "extract_attachments" );
+    action->setIcon( KIcon("document-save") );
+    action->setText( i18n("Extract &Attachments") );
+    connect(action, SIGNAL(triggered(bool)), m_mainWidget, SLOT( slotExtractAttachments() ));
+    action->setShortcut(QKeySequence(Qt::Key_F4));
 
-    new KAction( i18n("Clear Cache"), 0, this, SLOT( clearCache() ),
-                 actionCollection(), "clear_cache" );
+    action = actionCollection()->addAction( "clear_cache" );
+    action->setText( i18n("Clear Cache") );
+    connect(action, SIGNAL(triggered(bool) ), SLOT( clearCache() ));
 
-    new KAction( i18n("&Search by Product..."), "goto", CTRL+Qt::Key_P, this,
-                 SLOT( searchPackage() ), actionCollection(), "search_package" );
-    new KAction( i18n("Search by Bug &Number..."), "filefind", CTRL+Qt::Key_N, this,
-                 SLOT( searchBugNumber() ), actionCollection(), "search_bugnumber" );
+    action = actionCollection()->addAction( "search_package" );
+    action->setIcon( KIcon("go-jump") );
+    action->setText( i18n("&Search by Product...") );
+    connect(action, SIGNAL(triggered(bool)), SLOT( searchPackage() ));
+    action->setShortcut(QKeySequence(Qt::CTRL+Qt::Key_P));
+    action = actionCollection()->addAction( "search_bugnumber" );
+    action->setIcon( KIcon("edit-find") );
+    action->setText( i18n("Search by Bug &Number...") );
+    connect(action, SIGNAL(triggered(bool)), SLOT( searchBugNumber() ));
+    action->setShortcut(QKeySequence(Qt::CTRL+Qt::Key_N));
     // For now "Description" searches by title. Maybe later we can have a
     // full-text search interfacing bugs.kde.org and rename the current one to "By Title".
-    new KAction( i18n("Search by &Description...") ,"find", CTRL+Qt::Key_D, this,
-                 SLOT( searchDescription() ), actionCollection(), "search_description" );
+    action = actionCollection()->addAction( "search_description" );
+    action->setIcon( KIcon("edit-find") );
+    action->setText( i18n("Search by &Description...") );
+    connect(action, SIGNAL(triggered(bool)), SLOT( searchDescription() ));
+    action->setShortcut(QKeySequence(Qt::CTRL+Qt::Key_D));
 
-//    new KAction( i18n("&Merge"), "view_remove", CTRL+Qt::Key_M, m_mainWidget,
+//    new KAction( i18n("&Merge"), "view-close", CTRL+Qt::Key_M, m_mainWidget,
 //                 SLOT( mergeBugs() ), actionCollection(), "cmd_merge" );
-//    new KAction( i18n("&Unmerge"), "view_top_bottom", CTRL+SHIFT+Qt::Key_M, m_mainWidget,
+//    new KAction( i18n("&Unmerge"), "view-split-top-bottom", CTRL+SHIFT+Qt::Key_M, m_mainWidget,
 //                 SLOT( unmergeBugs() ), actionCollection(), "cmd_unmerge" );
-    new KAction( i18n("C&lose..."), "edittrash", CTRL+Qt::Key_L, m_mainWidget,
-                 SLOT( closeBug() ), actionCollection(), "cmd_close" );
-//    new KAction( i18n("Clos&e Silently"), "edittrash", CTRL+Qt::Key_E, m_mainWidget,
+    action = actionCollection()->addAction( "cmd_close" );
+    action->setIcon( KIcon("user-trash") );
+    action->setText( i18n("C&lose...") );
+    connect(action, SIGNAL(triggered(bool)), m_mainWidget, SLOT( closeBug() ));
+    action->setShortcut(QKeySequence(Qt::CTRL+Qt::Key_L));
+//    new KAction( i18n("Clos&e Silently"), "user-trash", CTRL+Qt::Key_E, m_mainWidget,
 //                 SLOT( closeBugSilently() ), actionCollection(), "cmd_close_silently" );
-    new KAction( i18n("Re&open"), "idea", CTRL+Qt::Key_O, m_mainWidget,
-                 SLOT( reopenBug() ), actionCollection(), "cmd_reopen" );
-//    new KAction( i18n("Re&assign..."), "folder_new", CTRL+Qt::Key_A, m_mainWidget,
+    action = actionCollection()->addAction( "cmd_reopen" );
+    action->setIcon( KIcon("edit-redo") );
+    action->setText( i18n("Re&open") );
+    connect(action, SIGNAL(triggered(bool)), m_mainWidget, SLOT( reopenBug() ));
+    action->setShortcut(QKeySequence(Qt::CTRL+Qt::Key_O));
+//    new KAction( i18n("Re&assign..."), "folder-new", CTRL+Qt::Key_A, m_mainWidget,
 //                 SLOT( reassignBug() ), actionCollection(), "cmd_reassign" );
-//    new KAction( i18n("Change &Title..."), "text_under", CTRL+Qt::Key_T, m_mainWidget,
+//    new KAction( i18n("Change &Title..."), "edit-rename", CTRL+Qt::Key_T, m_mainWidget,
 //                 SLOT( titleBug() ), actionCollection(), "cmd_title" );
-//    new KAction( i18n("Change &Severity..."), "edit", CTRL+Qt::Key_S, m_mainWidget,
+//    new KAction( i18n("Change &Severity..."), "document-properties", CTRL+Qt::Key_S, m_mainWidget,
 //                 SLOT( severityBug() ), actionCollection(), "cmd_severity" );
-    new KAction( i18n("&Reply..."), "mail_replyall",CTRL+Qt::Key_R , m_mainWidget,
-                 SLOT( replyBug() ), actionCollection(), "cmd_reply" );
-    new KAction( i18n("Reply &Privately..."), "mail_reply", CTRL+Qt::Key_I, m_mainWidget,
-                 SLOT( replyPrivateBug() ), actionCollection(), "cmd_replyprivate" );
+    action = actionCollection()->addAction( "cmd_reply" );
+    action->setIcon( KIcon("mail-reply-all") );
+    action->setText( i18n("&Reply...") );
+    connect(action, SIGNAL(triggered(bool)), m_mainWidget, SLOT( replyBug() ));
+    action->setShortcut(QKeySequence(Qt::CTRL+Qt::Key_R));
+    action = actionCollection()->addAction( "cmd_replyprivate" );
+    action->setIcon( KIcon("mail-reply-sender") );
+    action->setText( i18n("Reply &Privately...") );
+    connect(action, SIGNAL(triggered(bool)), m_mainWidget, SLOT( replyPrivateBug() ));
+    action->setShortcut(QKeySequence(Qt::CTRL+Qt::Key_I));
 
-    KStdAction::showMenubar(this, SLOT( slotToggleMenubar() ), actionCollection() );
-#if KDE_IS_VERSION( 3, 1, 90 )
+    KStandardAction::showMenubar(this, SLOT( slotToggleMenubar() ), actionCollection() );
     createStandardStatusBarAction();
     setStandardToolBarMenuEnabled(true);
-#endif
 
-    m_disconnectedAction = new KToggleAction( i18n("&Disconnected Mode"), 0,
-                                              this,
-                                              SLOT( slotDisconnectedAction() ),
-                                              actionCollection(),
-                                              "settings_disconnected" );
+    m_disconnectedAction = actionCollection()->add<KToggleAction>( "settings_disconnected" );
+    m_disconnectedAction->setText( i18n("&Disconnected Mode") );
+    connect(m_disconnectedAction, SIGNAL(triggered(bool)), SLOT( slotDisconnectedAction() ));
     m_disconnectedAction->setChecked( BugSystem::self()->disconnected() );
 
     // Bookmarks menu
-    m_pamBookmarks = new KActionMenu( i18n( "&Bookmarks" ), "bookmark", actionCollection(), "bookmarks" );
-    m_pBookmarkMenu = new KBookmarkMenu( KBBBookmarkManager::self(), this, m_pamBookmarks->popupMenu(), actionCollection(), true );
+    m_pamBookmarks = actionCollection()->add<KActionMenu>( "bookmarks" );
+    m_pamBookmarks->setText( i18n( "&Bookmarks" ) );
+    m_pBookmarkMenu = new KBookmarkMenu( KBBBookmarkManager::self(), this, m_pamBookmarks->menu(), actionCollection() );
 
-    KStdAction::preferences( this, SLOT(preferences()), actionCollection() );
+    KStandardAction::preferences( this, SLOT(preferences()), actionCollection() );
 
-    KToggleAction *toggleTmp =  new KToggleAction( i18n("Show Closed Bugs"), "recycled", 0, this, SLOT( slotToggleDone() ),
-                 actionCollection(), "cmd_toggle_done" );
-#if KDE_IS_VERSION( 3, 2, 90 )
-    toggleTmp->setCheckedState(i18n("Hide Closed Bugs"));
-#endif
+    KToggleAction *toggleTmp = actionCollection()->add<KToggleAction>( "cmd_toggle_done" );
+    toggleTmp->setIcon( KIcon("view-filter") );
+    toggleTmp->setText( i18n("Show Closed Bugs") );
+    connect(toggleTmp, SIGNAL(triggered(bool) ), SLOT( slotToggleDone() ));
+    toggleTmp->setCheckedState(KGuiItem(i18n("Hide Closed Bugs")));
     toggleTmp->setChecked( KBBPrefs::instance()->mShowClosedBugs );
 
-    toggleTmp =new KToggleAction( i18n("Show Wishes"), "bookmark", 0, this, SLOT( slotToggleWishes() ),
-                 actionCollection(), "cmd_toggle_wishes" );
-#if KDE_IS_VERSION( 3, 2, 90 )
-    toggleTmp->setCheckedState(i18n("Hide Wishes"));
-#endif
+    toggleTmp = actionCollection()->add<KToggleAction>( "cmd_toggle_wishes" );
+    toggleTmp->setIcon( KIcon("view-history") );
+    toggleTmp->setText( i18n("Show Wishes") );
+    connect(toggleTmp, SIGNAL(triggered(bool) ), SLOT( slotToggleWishes() ));
+    toggleTmp->setCheckedState(KGuiItem(i18n("Hide Wishes")));
     toggleTmp->setChecked(KBBPrefs::instance()->mShowWishes);
 
-    mSelectServerAction = new KSelectAction( i18n( "Select Server" ), 0, 0,
-                                             this,
-                                             SLOT( slotSelectServer() ),
-                                             actionCollection(),
-                                             "select_server" );
-
+    mSelectServerAction = actionCollection()->add<KSelectAction>( "select_server", this, SLOT( slotSelectServer() ) );
+    mSelectServerAction->setText( i18n( "Select Server" ) );
     setupSelectServerAction();
 
     if ( KBBPrefs::instance()->mDebugMode ) {
-      new KAction( i18n("Show Last Server Response..."), 0 , this,
-                   SLOT( showLastResponse() ), actionCollection(),
-                   "debug_lastresponse" );
-      new KAction( i18n("Show Bug HTML Source..."), 0 , this,
-                   SLOT( showBugSource() ), actionCollection(),
-                   "debug_showbugsource" );
+      action = actionCollection()->addAction( "debug_lastresponse" );
+      action->setText( i18n("Show Last Server Response...") );
+      connect(action, SIGNAL(triggered(bool) ), SLOT( showLastResponse() ));
+      action = actionCollection()->addAction( "debug_showbugsource" );
+      action->setText( i18n("Show Bug HTML Source...") );
+      connect(action, SIGNAL(triggered(bool) ), SLOT( showBugSource() ));
     }
 
-#if KDE_IS_VERSION( 3, 2, 90 )
     setupGUI( (ToolBar | Keys | StatusBar | Save | Create ), "kbugbusterui.rc" );
-#else
-    createGUI();
-#endif
 }
 
 void KBBMainWindow::slotToggleMenubar()
@@ -270,8 +308,8 @@ void KBBMainWindow::setupSelectServerAction()
 {
     QStringList servers;
     int current = -1;
-    QValueList<BugServer *> serverList = BugSystem::self()->serverList();
-    QValueList<BugServer *>::ConstIterator it;
+    QList<BugServer *> serverList = BugSystem::self()->serverList();
+    QList<BugServer *>::ConstIterator it;
     for ( it = serverList.begin(); it != serverList.end(); ++it ) {
       QString name = (*it)->serverConfig().name();
       servers.append( name );
@@ -285,7 +323,7 @@ void KBBMainWindow::setupSelectServerAction()
     }
 }
 
-QString KBBMainWindow::currentURL() const
+QString KBBMainWindow::currentUrl() const
 {
   QString number=m_mainWidget->currentNumber();
 
@@ -297,11 +335,12 @@ QString KBBMainWindow::currentURL() const
 
 QString KBBMainWindow::currentTitle() const
 {
-  return "#"+m_mainWidget->currentNumber()+": "+m_mainWidget->currentTitle();
+  return '#'+m_mainWidget->currentNumber()+": "+m_mainWidget->currentTitle();
 }
 
-void KBBMainWindow::openBookmarkURL( const QString & url )
+void KBBMainWindow::openBookmark(const KBookmark & bm, Qt::MouseButtons mb, Qt::KeyboardModifiers km)
 {
+    const QString & url = bm.url().url();
     if ( url.left(4)=="bug:" ) {
       QString bugnumber = url.mid(4);
       m_mainWidget->slotRetrieveBugDetails( Bug::fromNumber( bugnumber ) );
@@ -342,12 +381,12 @@ void KBBMainWindow::slotListChanges()
     if (list.count() > 0)
     {
        int ret = KMessageBox::questionYesNoList( this, i18n("List of pending commands:"),
-                                              list, QString::null, KStdGuiItem::clear(), KStdGuiItem::close() );
+                                              list, QString(), KStandardGuiItem::clear(), KStandardGuiItem::close() );
        if ( ret == KMessageBox::Yes )
        {
            // Ask for confirmation, it's too easy to click the wrong button in the above dlg box
            if ( KMessageBox::warningContinueCancel( this, i18n("Do you really want to delete all commands?"),
-                               i18n("Confirmation Required"), KGuiItem( i18n("&Delete"), "editdelete"), "clearcommands", true)
+                               i18n("Confirmation Required"), KGuiItem( i18n("&Delete"), "edit-delete"), KStandardGuiItem::cancel(), "clearcommands", KMessageBox::Notify)
                    == KMessageBox::Continue )
                BugSystem::self()->clearCommands();
        }
@@ -361,7 +400,7 @@ void KBBMainWindow::slotListChanges()
 void KBBMainWindow::slotSetPercent( unsigned long percent )
 {
     // KIO::Job::percent() shouldn't return an unsigned long. - Frerich
-    m_progressBar->setProgress( percent );
+    m_progressBar->setValue( percent );
 }
 
 void KBBMainWindow::searchPackage()
@@ -372,7 +411,7 @@ void KBBMainWindow::searchPackage()
     mPackageSelectDialog->setPackages( BugSystem::self()->packageList() );
     BugServerConfig cfg = BugSystem::self()->server()->serverConfig();
     QStringList recent = cfg.recentPackages();
-    kdDebug() << "MainWindow RECENT: " << recent.join(",") << endl;
+    kDebug() << "MainWindow RECENT: " << recent.join(",");
     mPackageSelectDialog->setRecentPackages( recent );
 
     mPackageSelectDialog->exec();
@@ -391,10 +430,10 @@ void KBBMainWindow::searchBugNumber()
     bool ok = false;
     QString result = KInputDialog::getText( i18n("Search for Bug Number"),
                                             i18n("Please enter a bug number:"),
-                                            QString::null, &ok, this );
+                                            QString(), &ok, this );
     if ( ok ) {
       //Strip whitespace and # if needed
-      result = result.stripWhiteSpace();
+      result = result.trimmed();
       if (result[0]=='#')
         result = result.mid(1);
     }
@@ -408,10 +447,10 @@ void KBBMainWindow::searchBugNumber()
 
 void KBBMainWindow::searchDescription()
 {
-    kdDebug() << "KBBMainWindow::searchDescription()." << endl;
+    kDebug() << "KBBMainWindow::searchDescription().";
     //KMessageBox::sorry(this,i18n("searchDescription(): to be implemented."),i18n("Not implemented"));
     KFindDialog dlg( this );
-    if ( dlg.exec() == KDialogBase::Accepted )
+    if ( dlg.exec() == KDialog::Accepted )
         m_mainWidget->searchBugByTitle( dlg.options(), dlg.pattern() );
 }
 
@@ -420,7 +459,7 @@ bool KBBMainWindow::queryClose()
     if ( ! BugSystem::self()->server()->commandsPending() ) return true;
 
     int result = KMessageBox::warningYesNoCancel(this,i18n("There are unsent bug commands."
-                                                           " Do you want to send them now?"), QString::null, i18n("Send"), i18n("Do Not Send"));
+                                                           " Do you want to send them now?"), QString(), KGuiItem(i18n("Send")), KGuiItem(i18n("Do Not Send")));
     if ( result == KMessageBox::Cancel ) return false;
     if ( result == KMessageBox::Yes ) {
         BugSystem::self()->sendCommands();
