@@ -19,7 +19,7 @@
 #include "bug.h"
 class Package;
 class BugDetails;
-class QProgressDialog;
+class KProgressDialog;
 
 class LoadAllBugsDlg : public QDialog
 {
@@ -36,7 +36,7 @@ private:
     Bug::List m_bugs;
     unsigned int m_processed;
     unsigned int m_count;
-    QProgressDialog* m_bugLoadingProgress;
+    KProgressDialog* m_bugLoadingProgress;
 };
 
 #endif
