@@ -12,8 +12,8 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
 /*
@@ -27,7 +27,7 @@
 #define MULTIVIEW_H
 
 #include <qsplitter.h>
-#include <qptrlist.h>
+#include <q3ptrlist.h>
 #include "traceitemview.h"
 #include "tabview.h" // because of QPtrList<TabView>
 
@@ -36,7 +36,7 @@ class MultiView : public QSplitter, public TraceItemView
   Q_OBJECT
 
 public:
-  MultiView(TopLevel* top, QWidget* parent = 0, const char* name = 0);
+  explicit MultiView(TopLevel* top, QWidget* parent = 0);
 
   QWidget* widget() { return this; }
   TabView* activeTabView() const { return _active; }
@@ -50,8 +50,8 @@ public:
   void selected(TraceItemView*, TraceItem*);
   void activated(TraceItemView*, TraceItem*);
 
-  void readViewConfig(KConfig*, QString prefix, QString postfix, bool);
-  void saveViewConfig(KConfig*, QString prefix, QString postfix, bool);
+  void readViewConfig(KConfig*, const QString& prefix, const QString& postfix, bool);
+  void saveViewConfig(KConfig*, const QString& prefix, const QString& postfix, bool);
 
 public slots:
     void tabActivated(TabView*);
@@ -60,7 +60,7 @@ public slots:
   void doUpdate(int);
 
   TabView* _active;
-  QPtrList<TabView> _views;
+  Q3PtrList<TabView> _views;
 };
 
 #endif
