@@ -12,8 +12,8 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
 /*
@@ -25,29 +25,31 @@
 
 #include "treemap.h"
 #include "tracedata.h"
+//Added by qt3to4:
+#include <QPixmap>
 
 class PartAreaWidget: public TreeMapWidget
 {
   Q_OBJECT
 
 public:
-  // Visualisation inside of trace parts
-  enum VisualisationMode { NoVisualisation, Partitioning, Inclusive };
+  // Visualization inside of trace parts
+  enum VisualizationMode { NoVisualization, Partitioning, Inclusive };
 
-  PartAreaWidget(QWidget* parent=0, const char* name=0);
+  PartAreaWidget(QWidget* parent=0);
 
   void setData(TraceData* d);
-  void setCostType(TraceCostType* ct);
+  void setEventType(TraceEventType* ct);
   void setGroupType(TraceCost::CostType gt);
-  void setVisualisation(VisualisationMode);
+  void setVisualization(VisualizationMode);
   void setZoomFunction(bool zoomFunction);
   void setCallLevels(int callLevels);
   void setFunction(TraceFunction* f);
 
-  TraceCostType* costType() const { return _costType; }
+  TraceEventType* eventType() const { return _eventType; }
   TraceCost::CostType groupType() const { return _groupType; }
   TraceFunction* function() const { return _function; }
-  VisualisationMode visualisation() const { return _visualisation; }
+  VisualizationMode visualization() const { return _visualization; }
   bool zoomFunction() const { return _zoomFunction; }
   int callLevels() const { return _callLevels; }
 
@@ -61,10 +63,10 @@ private:
   void refreshParts();
 
   TraceData* _data;
-  TraceCostType* _costType;
+  TraceEventType* _eventType;
   TraceCost::CostType _groupType;
   TraceFunction* _function;
-  VisualisationMode _visualisation;
+  VisualizationMode _visualization;
   bool _zoomFunction;
   int _callLevels;
 
