@@ -12,14 +12,14 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
 #ifndef PARTLISTITEM_H
 #define PARTLISTITEM_H
 
-#include <qlistview.h>
+#include <q3listview.h>
 #include "tracedata.h"
 
 /**
@@ -29,15 +29,15 @@
  *
  * Note: on a cost item / percentage change, the list is rebuild
  */
-class PartListItem: public QListViewItem
+class PartListItem: public Q3ListViewItem
 {
 public:
-  PartListItem(QListView* parent, TraceCostItem* costItem,
-               TraceCostType* ct, TraceCost::CostType gt, TracePart* part);
+  PartListItem(Q3ListView* parent, TraceCostItem* costItem,
+               TraceEventType* ct, TraceCost::CostType gt, TracePart* part);
 
-  int compare(QListViewItem * i, int col, bool ascending ) const;
+  int compare(Q3ListViewItem * i, int col, bool ascending ) const;
   TraceCost* partCostItem() { return _partCostItem; }
-  void setCostType(TraceCostType* ct);
+  void setCostType(TraceEventType* ct);
   void setGroupType(TraceCost::CostType);
   TracePart* part() { return _part; }
   void update();
@@ -45,7 +45,7 @@ public:
 private:
   SubCost _sum, _pure;
   SubCost _callers;
-  TraceCostType* _costType;
+  TraceEventType* _costType;
   TraceCost* _partCostItem;
   TracePart* _part;
   TraceCost::CostType _groupType;
