@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: kdeaccountsformat.h 174706 2002-08-30 22:44:18Z pfeiffer $
+** $Id: kdeaccountsformat.h 704941 2007-08-26 17:24:56Z amth $
 **
 ** Created : 2001
 **
@@ -7,16 +7,16 @@
 **
 ****************************************************************************/
 
-#ifndef KDEACCOUNTSPARSER_H
-#define KDEACCOUNTSPARSER_H
+#ifndef KDEACCOUNTSFORMAT_H
+#define KDEACCOUNTSFORMAT_H
 
-#include <kabc/formatplugin.h>
+#include <kabc/format.h>
 
 namespace KABC {
     class AddressBook;
 }
 
-class KDEAccountsFormat : public KABC::FormatPlugin
+class KDEAccountsFormat : public KABC::Format
 {
 public:
     KDEAccountsFormat() {}
@@ -48,4 +48,4 @@ public:
 
 };
 
-#endif // KDEACCOUNTSPARSER_H
+#endif // KDEACCOUNTSFORMAT_H
