@@ -25,7 +25,6 @@
 #include <QtGui/QSpinBox>
 #include <QtGui/QVBoxLayout>
 #include <QtGui/QHBoxLayout>
-#include <QtGui/QTabWidget>
 #include <QtGui/QToolTip>
 
 #include <kbuttongroup.h>
@@ -38,6 +37,7 @@
 #include <kurlcombobox.h>
 #include <kurlrequester.h>
 #include <kservicetypetrader.h>
+#include <ktabwidget.h>
 
 #include <kparts/componentfactory.h>
 #include <kregexpeditorinterface.h>
@@ -47,7 +47,7 @@
 
 DiffPage::DiffPage() : PageBase(), m_ignoreRegExpDialog( 0 )
 {
-	m_tabWidget = new QTabWidget( this );
+	m_tabWidget = new KTabWidget( this );
 
 	addDiffTab();
 
@@ -226,7 +226,7 @@ void DiffPage::addDiffTab()
 	layout->addStretch( 1 );
 	page->setMinimumSize( sizeHintForWidget( page ) );
 
-	m_tabWidget->addTab( page, i18n( "&Diff" ) );
+	m_tabWidget->addTab( page, i18n( "Diff" ) );
 }
 
 void DiffPage::addFormatTab()
@@ -272,7 +272,7 @@ void DiffPage::addFormatTab()
 	layout->addStretch( 1 );
 	page->setMinimumSize( sizeHintForWidget( page ) );
 
-	m_tabWidget->addTab( page, i18n( "&Format" ) );
+	m_tabWidget->addTab( page, i18n( "Format" ) );
 }
 
 void DiffPage::addOptionsTab()
@@ -346,7 +346,7 @@ void DiffPage::addOptionsTab()
 	layout->addStretch( 1 );
 	page->setMinimumSize( sizeHintForWidget( page ) );
 
-	m_tabWidget->addTab( page, i18n( "O&ptions" ) );
+	m_tabWidget->addTab( page, i18n( "Options" ) );
 }
 
 void DiffPage::addExcludeTab()
@@ -360,7 +360,10 @@ void DiffPage::addExcludeTab()
 	excludeFilePatternGroupBox->setTitle( i18n( "File Pattern to Exclude" ) );
 	m_excludeFilePatternCheckBox = new QCheckBox( "", excludeFilePatternGroupBox );
 	QToolTip::add( m_excludeFilePatternCheckBox, i18n( "If this is checked you can enter a shell pattern in the text box on the right or select entries from the list." ) );
-	m_excludeFilePatternEditListBox = new KEditListBox( excludeFilePatternGroupBox, "exclude_file_pattern_editlistbox", false, KEditListBox::Add|KEditListBox::Remove );
+	m_excludeFilePatternEditListBox = new KEditListBox( excludeFilePatternGroupBox );
+	m_excludeFilePatternEditListBox->setObjectName( "exclude_file_pattern_editlistbox" );
+	m_excludeFilePatternEditListBox->setButtons( KEditListBox::Add|KEditListBox::Remove );
+	m_excludeFilePatternEditListBox->setCheckAtEntering( false );
 	QToolTip::add( m_excludeFilePatternEditListBox, i18n( "Here you can enter or remove a shell pattern or select one or more entries from the list." ) );
 	layout->addWidget( excludeFilePatternGroupBox );
 
@@ -384,7 +387,7 @@ void DiffPage::addExcludeTab()
 	layout->addStretch( 1 );
 	page->setMinimumSize( sizeHintForWidget( page ) );
 
-	m_tabWidget->addTab( page, i18n( "&Exclude" ) );
+	m_tabWidget->addTab( page, i18n( "Exclude" ) );
 }
 
 #include "diffpage.moc"
