@@ -1,11 +1,9 @@
 /***************************************************************************
-                                diffhunk.h  -  description
-                                -------------------
+                                diffhunk.h
+                                ----------
         begin                   : Sun Mar 4 2001
-        copyright               : (C) 2001-2003 by Otto Bruggeman
-                                  and John Firebaugh
-        email                   : otto.bruggeman@home.nl
-                                  jfirebaugh@kde.org
+        Copyright 2001-2003 Otto Bruggeman <otto.bruggeman@home.nl>
+        Copyright 2001-2003 John Firebaugh <jfirebaugh@kde.org>
 ****************************************************************************/
 
 /***************************************************************************
@@ -22,6 +20,8 @@
 
 #include "difference.h"
 
+#include <Q3ValueList>
+
 namespace Diff2
 {
 
@@ -33,7 +33,7 @@ public:
 	enum Type { Normal, AddedByBlend };
 
 public:
-	DiffHunk( int sourceLine, int destinationLine, QString function = QString::null, Type type = Normal );
+	DiffHunk( int sourceLine, int destinationLine, QString function = QString(), Type type = Normal );
 	~DiffHunk();
 
 	const DifferenceList& differences() const { return m_differences; };
@@ -60,9 +60,9 @@ private:
 	Type           m_type;
 };
 
-typedef QValueList<DiffHunk*> DiffHunkList;
-typedef QValueList<DiffHunk*>::iterator DiffHunkListIterator;
-typedef QValueList<DiffHunk*>::const_iterator DiffHunkListConstIterator;
+typedef Q3ValueList<DiffHunk*> DiffHunkList;
+typedef Q3ValueList<DiffHunk*>::iterator DiffHunkListIterator;
+typedef Q3ValueList<DiffHunk*>::const_iterator DiffHunkListConstIterator;
 
 } // End of namespace Diff2
 
