@@ -2,8 +2,8 @@
 **
 ** Filename   : levenshteintable.cpp
 ** Created on : 08 november, 2003
-** Copyright  : (c) 2003 Otto Bruggeman
-** Email      : bruggie@home.nl
+** Copyright 2003 Otto Bruggeman <bruggie@home.nl>
+** Copyright 2007 Kevin Kofler   <kevin.kofler@chello.at>
 **
 *******************************************************************************/
 
@@ -16,15 +16,15 @@
 **
 *******************************************************************************/
 
+#include "levenshteintable.h"
+
 #include <iostream>
 
-#include <qstring.h>
+#include <QtCore/QString>
 
 #include <kdebug.h>
 #include <kglobal.h>
 
-#include "levenshteintable.h"
-
 #include "difference.h"
 
 using namespace Diff2;
@@ -58,7 +58,7 @@ LevenshteinTable::~LevenshteinTable()
 
 int LevenshteinTable::getContent( unsigned int posX, unsigned int posY ) const
 {
-//	kdDebug(8101) << "Width = " << m_width << ", height = " << m_height << ", posX = " << posX << ", posY = " << posY << endl;
+//	kDebug(8101) << "Width = " << m_width << ", height = " << m_height << ", posX = " << posX << ", posY = " << posY << endl;
 	return m_table[ posY * m_width + posX ];
 }
 
@@ -107,8 +107,8 @@ unsigned int LevenshteinTable::createTable( DifferenceString* source, Difference
 	m_source      = source;
 	m_destination = destination;
 
-	QString s = ' ' + source->string();      // Optimization, so i dont have to subtract 1 from the indexes every 
-	QString d = ' ' + destination->string(); // single time and add 1 to the width and height of the table
+	QString s = ' ' + source->string();      // Optimization, so i do not have to subtract 1 from the indexes
+	QString d = ' ' + destination->string(); // every single time and add 1 to the width and height of the table
 
 	unsigned int m = s.length();
 	unsigned int n = d.length();
@@ -141,11 +141,11 @@ unsigned int LevenshteinTable::createTable( DifferenceString* source, Difference
 	// Optimization, calculate row wise instead of column wise, wont trash the cache so much with large strings
 	for ( j = 1; j < n; ++j )
 	{
-		dj = dq[ j ];
+		dj = dq[j].unicode();
 
 		for ( i = 1; i < m; ++i )
 		{
-			si = sq[ i ];
+			si = sq[i].unicode();
 			if ( si == dj )
 				cost = 0;
 			else
@@ -155,7 +155,7 @@ unsigned int LevenshteinTable::createTable( DifferenceString* source, Difference
 			west      = getContent( i-1, j ) + 1;
 			northwest = getContent( i-1, j-1 ) + cost;
 
-			setContent( i, j, kMin( north, kMin( west, northwest ) ) );
+			setContent( i, j, qMin( north, qMin( west, northwest ) ) );
 		}
 	}
 
@@ -164,7 +164,7 @@ unsigned int LevenshteinTable::createTable( DifferenceString* source, Difference
 
 int LevenshteinTable::chooseRoute( int c1, int c2, int c3 )
 {
-//	kdDebug(8101) << "c1 = " << c1 << ", c2 = " << c2 << ", c3 = " << c3 << endl;
+//	kDebug(8101) << "c1 = " << c1 << ", c2 = " << c2 << ", c3 = " << c3 << endl;
 	// preference order: c2, c3, c1, hopefully this will work out for me
 	if ( c2 <= c1 && c2 <= c3 )
 		return 1;
@@ -200,8 +200,8 @@ void LevenshteinTable::createListsOfMarkers()
 		switch ( direction )
 		{
 		case 0: // north
-//			kdDebug(8101) << "Picking north" << endl;
-//			kdDebug(8101) << "Source[" << ( x - 1 ) << "] = " << QString( source[ x-1 ] ) << ", destination[" << ( y - 1 ) << "] = " << QString( destination[ y-1 ] ) << endl;
+//			kDebug(8101) << "Picking north" << endl;
+//			kDebug(8101) << "Source[" << ( x - 1 ) << "] = " << QString( source[ x-1 ] ) << ", destination[" << ( y - 1 ) << "] = " << QString( destination[ y-1 ] ) << endl;
 
 			if ( !m_destination->markerList().isEmpty() )
 				c = m_destination->markerList().first();
@@ -210,14 +210,14 @@ void LevenshteinTable::createListsOfMarkers()
 
 			if ( c && c->type() == Marker::End )
 			{
-//				kdDebug(8101) << "CurrentValue: " << currentValue << endl;
+//				kDebug(8101) << "CurrentValue: " << currentValue << endl;
 				if ( n == currentValue )
 					m_destination->prepend( new Marker( Marker::Start, y ) );
-				// else: the change continues, dont do anything
+				// else: the change continues, do not do anything
 			}
 			else
 			{
-//				kdDebug(8101) << "CurrentValue: " << currentValue << endl;
+//				kDebug(8101) << "CurrentValue: " << currentValue << endl;
 				if ( n < currentValue )
 					m_destination->prepend( new Marker( Marker::End, y ) );
 			}
@@ -225,8 +225,8 @@ void LevenshteinTable::createListsOfMarkers()
 			--y;
 			break;
 		case 1: // northwest
-//			kdDebug(8101) << "Picking northwest" << endl;
-//			kdDebug(8101) << "Source[" << ( x - 1 ) << "] = " << QString( source[ x-1 ] ) << ", destination[" << ( y - 1 ) << "] = " << QString( destination[ y-1 ] ) << endl;
+//			kDebug(8101) << "Picking northwest" << endl;
+//			kDebug(8101) << "Source[" << ( x - 1 ) << "] = " << QString( source[ x-1 ] ) << ", destination[" << ( y - 1 ) << "] = " << QString( destination[ y-1 ] ) << endl;
 
 			if ( !m_destination->markerList().isEmpty() )
 				c = m_destination->markerList().first();
@@ -235,14 +235,14 @@ void LevenshteinTable::createListsOfMarkers()
 
 			if ( c && c->type() == Marker::End )
 			{
-//				kdDebug(8101) << "End found: CurrentValue: " << currentValue << endl;
+//				kDebug(8101) << "End found: CurrentValue: " << currentValue << endl;
 				if ( nw == currentValue )
 					m_destination->prepend( new Marker( Marker::Start, y ) );
-				// else: the change continues, dont do anything
+				// else: the change continues, do not do anything
 			}
 			else
 			{
-//				kdDebug(8101) << "CurrentValue: " << currentValue << endl;
+//				kDebug(8101) << "CurrentValue: " << currentValue << endl;
 				if ( nw < currentValue )
 					m_destination->prepend( new Marker( Marker::End, y ) );
 			}
@@ -254,14 +254,14 @@ void LevenshteinTable::createListsOfMarkers()
 
 			if ( c && c->type() == Marker::End )
 			{
-//				kdDebug(8101) << "End found: CurrentValue: " << currentValue << endl;
+//				kDebug(8101) << "End found: CurrentValue: " << currentValue << endl;
 				if ( nw == currentValue )
 					m_source->prepend( new Marker( Marker::Start, x ) );
-				// else: the change continues, dont do anything
+				// else: the change continues, do not do anything
 			}
 			else
 			{
-//				kdDebug(8101) << "CurrentValue: " << currentValue << endl;
+//				kDebug(8101) << "CurrentValue: " << currentValue << endl;
 				if ( nw < currentValue )
 					m_source->prepend( new Marker( Marker::End, x ) );
 			}
@@ -270,8 +270,8 @@ void LevenshteinTable::createListsOfMarkers()
 			--x;
 			break;
 		case 2: // west
-//			kdDebug(8101) << "Picking west" << endl;
-//			kdDebug(8101) << "Source[" << ( x - 1 ) << "] = " << QString( source[ x-1 ] ) << ", destination[" << ( y - 1 ) << "] = " << QString( destination[ y-1 ] ) << endl;
+//			kDebug(8101) << "Picking west" << endl;
+//			kDebug(8101) << "Source[" << ( x - 1 ) << "] = " << QString( source[ x-1 ] ) << ", destination[" << ( y - 1 ) << "] = " << QString( destination[ y-1 ] ) << endl;
 
 			if ( !m_source->markerList().isEmpty() )
 				c = m_source->markerList().first();
@@ -280,14 +280,14 @@ void LevenshteinTable::createListsOfMarkers()
 
 			if ( c && c->type() == Marker::End )
 			{
-//				kdDebug(8101) << "End found: CurrentValue: " << currentValue << endl;
+//				kDebug(8101) << "End found: CurrentValue: " << currentValue << endl;
 				if ( w == currentValue )
 					m_source->prepend( new Marker( Marker::Start, x ) );
-				// else: the change continues, dont do anything
+				// else: the change continues, do not do anything
 			}
 			else
 			{
-//				kdDebug(8101) << "CurrentValue: " << currentValue << endl;
+//				kDebug(8101) << "CurrentValue: " << currentValue << endl;
 				if ( w < currentValue )
 					m_source->prepend( new Marker( Marker::End, x ) );
 			}
@@ -297,13 +297,13 @@ void LevenshteinTable::createListsOfMarkers()
 		}
 	}
 
-//	kdDebug(8101) << "Source string: " << m_source->string() << endl;
+//	kDebug(8101) << "Source string: " << m_source->string() << endl;
 //	c = m_source->markerList()->first();
 //	QStringList list;
 //	unsigned int prevValue = 0;
 //	for ( ; c; c = m_source->markerList()->next() )
 //	{
-//		kdDebug(8101) << "Source Marker Entry : Type: " << c->type() << ", Offset: " << c->offset() << endl;
+//		kDebug(8101) << "Source Marker Entry : Type: " << c->type() << ", Offset: " << c->offset() << endl;
 //		list.append( m_source->string().mid( prevValue, c->offset() - prevValue ) );
 //		prevValue = c->offset();
 //	}
@@ -311,15 +311,15 @@ void LevenshteinTable::createListsOfMarkers()
 //	{
 //		list.append( m_source->string().mid( prevValue, m_source->string().length() - prevValue ) );
 //	}
-//	kdDebug(8101) << "Source Resulting stringlist : " << list.join("\n") << endl;
+//	kDebug(8101) << "Source Resulting stringlist : " << list.join("\n") << endl;
 
 //	list.clear();
 //	prevValue = 0;
 
-//	kdDebug(8101) << "Destination string: " << m_destination->string() << endl;
+//	kDebug(8101) << "Destination string: " << m_destination->string() << endl;
 //	for ( ; c; c = m_destination->markerList()->next() )
 //	{
-//		kdDebug(8101) << "Destination Marker Entry : Type: " << c->type() << ", Offset: " << c->offset() << endl;
+//		kDebug(8101) << "Destination Marker Entry : Type: " << c->type() << ", Offset: " << c->offset() << endl;
 //		list.append( m_destination->string().mid( prevValue, c->offset() - prevValue ) );
 //		prevValue = c->offset();
 //	}
@@ -327,6 +327,6 @@ void LevenshteinTable::createListsOfMarkers()
 //	{
 //		list.append( m_destination->string().mid( prevValue, m_destination->string().length() - prevValue ) );
 //	}
-//	kdDebug(8101) << "Destination Resulting string : " << list.join("\n") << endl;
+//	kDebug(8101) << "Destination Resulting string : " << list.join("\n") << endl;
 }
 
