@@ -1,11 +1,29 @@
 /* vi: ts=8 sts=4 sw=4
  *
- * $Id: libkstartperf.c 234445 2003-06-29 01:09:41Z garbanzo $
+ * $Id: libkstartperf.c 758880 2008-01-09 13:05:37Z mueller $
  *
  * libkstartperf.c: LD_PRELOAD library for startup time measurements.
  *
  * Copyright (C) 2000 Geert Jansen <jansen@kde.org>
  *
+ *  Permission to use, copy, modify, and distribute this software
+ *  and its documentation for any purpose and without fee is hereby
+ *  granted, provided that the above copyright notice appear in all
+ *  copies and that both that the copyright notice and this
+ *  permission notice and warranty disclaimer appear in supporting
+ *  documentation, and that the name of the author not be used in
+ *  advertising or publicity pertaining to distribution of the
+ *  software without specific, written prior permission.
+ *
+ *  The author disclaim all warranties with regard to this
+ *  software, including all implied warranties of merchantability
+ *  and fitness.  In no event shall the author be liable for any
+ *  special, indirect or consequential damages or any damages
+ *  whatsoever resulting from loss of use, data or profits, whether
+ *  in an action of contract, negligence or other tortious action,
+ *  arising out of or in connection with the use or performance of
+ *  this software.
+ *
  * Based heavily on kmapnotify.c:
  * 
  * (C) 2000 Rik Hemsley <rik@kde.org>
@@ -23,7 +41,7 @@
 #include <X11/X.h>
 #include <X11/Xlib.h>
 
-#include <ltdl.h>
+#include <dlfcn.h>
 
 
 /* Prototypes */
@@ -64,11 +82,11 @@ int XMapRaised(Display * d, Window w)
 
 void KDE_InterceptXMapRequest(Display * d, Window w)
 {
-    lt_dlhandle handle;
+    void* handle;
 
-    handle = lt_dlopen("libX11.so");
+    handle = dlopen("libX11.so", RTLD_LAZY);
     if (handle == 0L)
-	handle = lt_dlopen("libX11.so.6");
+	handle = dlopen("libX11.so.6", RTLD_LAZY);
 
     if (handle == 0L)
     {
@@ -76,14 +94,14 @@ void KDE_InterceptXMapRequest(Display * d, Window w)
 	exit(1);
     }
 
-    KDE_RealXMapWindow = (KDE_XMapRequestSignature)lt_dlsym(handle, "XMapWindow");
+    KDE_RealXMapWindow = (KDE_XMapRequestSignature)dlsym(handle, "XMapWindow");
     if (KDE_RealXMapWindow == 0L)
     {
 	fprintf(stderr, "kstartperf: Could not find symbol XMapWindow in libX11\n");
 	exit(1);
     }
 
-    KDE_RealXMapRaised = (KDE_XMapRequestSignature)lt_dlsym(handle, "XMapRaised");
+    KDE_RealXMapRaised = (KDE_XMapRequestSignature)dlsym(handle, "XMapRaised");
     if (KDE_RealXMapRaised == 0L)
     {
 	fprintf(stderr, "kstartperf: Could not find symbol XMapRaised in libX11\n");
