@@ -1,5 +1,5 @@
 /* ****************************************************************************
-  This file is part of KAider (some bits of KBabel code were reused)
+  This file is part of Lokalize (some bits of KBabel code were reused)
 
   Copyright (C) 2007-2008 by Nick Shaforostoff <shafff@ukr.net>
   Copyright (C) 1999-2000 by Matthias Kiefer <matthias.kiefer@gmx.de>
@@ -45,7 +45,11 @@
 
 #include <QLabel>
 #include <QHBoxLayout>
-//#include <QTreeView>
+
+
+#ifdef XLIFF
+#include <QPixmap>
+#endif
 
 #include <ktabbar.h>
 #include <kled.h>
@@ -71,32 +75,35 @@ public:
 
         QHBoxLayout* layout=new QHBoxLayout(this);
         layout->addStretch();
-        layout->addWidget(new QLabel(i18nc("@label whether entry is fuzzy","Fuzzy:")));
+        layout->addWidget(new QLabel(i18nc("@label whether entry is fuzzy","Fuzzy:"),this));
         layout->addWidget(ledFuzzy=new KLed(colorScheme.foreground(KColorScheme::NeutralText)/*Qt::green*/,KLed::Off,KLed::Sunken,KLed::Rectangular));
-        layout->addWidget(new QLabel(i18nc("@label whether entry is fuzzy","Untranslated:")));
+        layout->addWidget(new QLabel(i18nc("@label whether entry is untranslated","Untranslated:"),this));
         layout->addWidget(ledUntr=new KLed(colorScheme.foreground(KColorScheme::NegativeText)/*Qt::red*/,KLed::Off,KLed::Sunken,KLed::Rectangular));
+        layout->addSpacing(1);
+        layout->addWidget(lblColumn=new QLabel(this));
         layout->addStretch();
         setMaximumHeight(minimumSizeHint().height());
     }
 
 //NOTE the config shit doesn't work
-// private:
-//     void contextMenuEvent(QContextMenuEvent* event)
-//     {
-//         QMenu menu;
-//         menu.addAction(i18nc("@action","Hide"));
-//         if (menu.exec(event->globalPos()))
-//         {
-//             Settings::setLeds(false);
-//             kWarning() << Settings::leds();
-//             hide();
-//         }
-//     }
+private:
+    void contextMenuEvent(QContextMenuEvent* event)
+    {
+        QMenu menu;
+        menu.addAction(i18nc("@action","Hide"));
+        if (menu.exec(event->globalPos()))
+        {
+            Settings::setLeds(false);
+            Settings::self()->writeConfig();
+            hide();
+        }
+    }
 
 public:
     KLed* ledFuzzy;
     KLed* ledUntr;
-    KLed* ledErr;
+    //KLed* ledErr;
+    QLabel* lblColumn;
 
 };
 
@@ -135,9 +142,127 @@ QString ProperTextEdit::toPlainText()
     cursor.select(QTextCursor::Document);
     QString text=cursor.selectedText();
     text.replace(QChar(8233),'\n');
+/*
+    int ii=text.size();
+    while(--ii>=0)
+        kWarning()<<text.at(ii).unicode();
+*/
     return text;
 }
 
+
+#ifdef XLIFF
+//BEGIN XLIFF
+
+
+inline static QImage generateImage(QString str, ProperTextEdit* w)
+{
+    str.prepend(' ');
+    QFontMetrics metrics(w->currentFont());
+    QRect rect=metrics.boundingRect(str);
+    rect.moveTo(0,0);
+
+    QLabel test(str,w);
+    test.setGeometry(rect);
+
+    QPixmap pixmap=QPixmap::grabWidget(&test,rect);
+    return pixmap.toImage();
+
+}
+
+void ProperTextEdit::setContent(const CatalogString& catStr)
+{
+    //kWarning()<<str<<ranges.size();
+    //prevent undo tracking system from recording this 'action'
+    document()->blockSignals(true);
+    clear();
+    QTextCursor cur=textCursor();
+
+
+    static const char* inlineElementNames[(int)InlineElementCount]={
+    "_unknown",
+    "bpt",
+    "ept",
+    "ph",
+    "it",
+//    "_NEVERSHOULDBECHOSEN",
+    "mrk",
+    "g",
+    "sub",
+    "_NEVERSHOULDBECHOSEN",
+    "x",
+    "bx",
+    "ex",
+    };
+
+    QMap<int,int> posToTagRange;
+    int i=catStr.ranges.size();
+    while(--i>=0)
+    {
+        posToTagRange.insert(catStr.ranges.at(i).start,i);
+        posToTagRange.insert(catStr.ranges.at(i).end,i);
+    }
+
+
+
+    i=0;
+    int prev=0;
+    while ((i = catStr.string.indexOf(TAGRANGE_IMAGE_SYMBOL, i)) != -1)
+    {
+        kWarning()<<"HAPPENED!!";
+        int tagRangeIndex=posToTagRange.value(i);
+        cur.insertText(catStr.string.mid(prev,i-prev));
+
+        TagRange ourRange=catStr.ranges.at(tagRangeIndex);
+        QString name=' '+ourRange.id;
+        QString text=QString::number(tagRangeIndex);
+        if (ourRange.start!=ourRange.end)
+        {
+//             kWarning()<<"a"<<ranges.at(tagRangeIndex).start;
+//             kWarning()<<"b"<<i;
+            if (ourRange.start==i)
+            {
+                text.append(" {");
+                name.append("-start");
+            }
+            else
+            {
+                text.prepend("} ");
+                name.append("-end");
+            }
+        }
+        document()->addResource(QTextDocument::ImageResource, QUrl(name), generateImage(text,this));
+        cur.insertImage(name);//NOTE what if twice the same name?
+
+        prev=++i;
+    }
+    cur.insertText(catStr.string.mid(prev));
+
+    document()->blockSignals(false);
+}
+
+//END XLIFF
+#endif
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 KAiderView::KAiderView(QWidget *parent,Catalog* catalog/*,keyEventHandler* kh*/)
     : QSplitter(Qt::Vertical,parent)
     , _catalog(catalog)
@@ -145,15 +270,14 @@ KAiderView::KAiderView(QWidget *parent,Catalog* catalog/*,keyEventHandler* kh*/)
     , _msgstrEdit(new ProperTextEdit(this))
     , m_msgidHighlighter(new SyntaxHighlighter(_msgidEdit->document()))
     , m_msgstrHighlighter(new SyntaxHighlighter(_msgstrEdit->document()))
-/*    , m_msgidHighlighter(0)
-    , m_msgstrHighlighter(0)*/
-    , _tabbar(new KTabBar(this))
+    , m_pluralTabBar(new KTabBar(this))
     , _leds(0)
     , _currentEntry(-1)
     , m_approvementState(true)
+    , m_modifiedAfterFind(false)
 {
     //( new QTreeView(this) )->selectAll();
-    _tabbar->hide();
+    m_pluralTabBar->hide();
 //     _msgidEdit->setWhatsThis(i18n("<qt><p><b>Original String</b></p>\n"
 //                                   "<p>This part of the window shows the original message\n"
 //                                   "of the currently displayed entry.</p></qt>"));
@@ -162,16 +286,22 @@ KAiderView::KAiderView(QWidget *parent,Catalog* catalog/*,keyEventHandler* kh*/)
 
     //apply changes to catalog via undo/redo
     connect (_msgstrEdit->document(), SIGNAL(contentsChange(int,int,int)), this, SLOT(contentsChanged(int,int,int)));
+    connect (_msgstrEdit, SIGNAL(cursorPositionChanged()), this, SLOT(cursorPositionChanged()));
+
 
     _msgidEdit->setUndoRedoEnabled(false);
     _msgstrEdit->setUndoRedoEnabled(false);
     _msgstrEdit->setAcceptRichText(false);
     _msgstrEdit->installEventFilter(this);
+    _msgidEdit->installEventFilter(this);
 
-    addWidget(_tabbar);
+    addWidget(m_pluralTabBar);
     addWidget(_msgidEdit);
     addWidget(_msgstrEdit);
 
+    QWidget::setTabOrder(_msgstrEdit,_msgidEdit);
+    QWidget::setTabOrder(_msgidEdit,_msgstrEdit);
+    setFocusProxy(_msgstrEdit);
 //     QTimer::singleShot(3000,this,SLOT(setupWhatsThis()));
     settingsChanged();
 }
@@ -181,7 +311,7 @@ KAiderView::~KAiderView()
     /*
     delete _msgidEdit;
     delete _msgstrEdit;
-    delete _tabbar;
+    delete m_pluralTabBar;
     */
 }
 
@@ -210,17 +340,28 @@ static bool isMasked(const QString& str, uint col)
 }
 
 
-bool KAiderView::eventFilter(QObject * /*obj*/, QEvent *event)
+bool KAiderView::eventFilter(QObject* obj, QEvent* event)
 {
-//     if (obj!=_msgstrEdit)
-//     {
-//         kWarning() << "THIS IS VERY STRANGE";
-//         return QSplitter::eventFilter(obj, event);
-//     }
-
     if (event->type() != QEvent::KeyPress)
         return false;//QObject::eventFilter(obj, event);
     QKeyEvent *keyEvent = static_cast<QKeyEvent *>(event);
+
+
+
+    if(keyEvent->matches(QKeySequence::MoveToPreviousPage))
+    {
+        emit signalGotoPrev();
+        return true;
+    }
+    else if(keyEvent->matches(QKeySequence::MoveToNextPage))
+    {
+        emit signalGotoNext();
+        return true;
+    }
+    if (obj!=_msgstrEdit)
+        return false;
+
+
     static QString spclChars("abfnrtv'\"?\\");
     if(keyEvent->matches(QKeySequence::Undo))
     {
@@ -240,16 +381,6 @@ bool KAiderView::eventFilter(QObject * /*obj*/, QEvent *event)
             return true;
         }
     }
-    else if(keyEvent->matches(QKeySequence::MoveToPreviousPage))
-    {
-        emit signalGotoPrev();
-        return true;
-    }
-    else if(keyEvent->matches(QKeySequence::MoveToNextPage))
-    {
-        emit signalGotoNext();
-        return true;
-    }
     else if (keyEvent->modifiers() == (Qt::AltModifier|Qt::ControlModifier))
     {
         if(keyEvent->key()==Qt::Key_Home)
@@ -269,6 +400,7 @@ bool KAiderView::eventFilter(QObject * /*obj*/, QEvent *event)
         //-BkSpace was hit and cursor was atStart
         //-Del was hit and cursor was atEnd
         if (KDE_ISUNLIKELY( !_catalog->isApproved(_currentEntry) && !_msgstrEdit->textCursor().hasSelection() ))
+                          //&& (_msgstrEdit->textCursor().atStart()||_msgstrEdit->textCursor().atEnd()) ))
             toggleApprovement(true);
         return false;
     }
@@ -303,7 +435,7 @@ bool KAiderView::eventFilter(QObject * /*obj*/, QEvent *event)
                    &&!isMasked(str,pos-1))
                     ins='\\';
                 // if there is no new line at the end
-                if(pos<2||str.mid(pos-2,2)!="\\n")
+                if(pos<2||str.midRef(pos-2,2)!="\\n")
                     ins+=' ';
             }
             else if(str.isEmpty())
@@ -313,8 +445,7 @@ bool KAiderView::eventFilter(QObject * /*obj*/, QEvent *event)
         }
         if (!str.isEmpty())
             ins+='\n';
-        t.insertText(ins);
-        _msgstrEdit->setTextCursor(t);
+        _msgstrEdit->insertPlainText(ins);
 
         return true;
     }
@@ -333,11 +464,9 @@ bool KAiderView::eventFilter(QObject * /*obj*/, QEvent *event)
             int pos=t.position();
             QString str=_msgstrEdit->toPlainText();
             if(!str.isEmpty()
-//                 &&pos<str.length()
                 &&str.at(pos) == '\\'
                 &&!isMasked(str,pos))
             {
-//                 QString spclChars="abfnrtv'\"?\\";
                 if(pos<str.length()-1&&spclChars.contains(str.at(pos+1)))
                     t.deleteChar();
             }
@@ -348,7 +477,7 @@ bool KAiderView::eventFilter(QObject * /*obj*/, QEvent *event)
 
         return true;
     }
-    else if( keyEvent->key()==Qt::Key_Backspace
+    else if( (!keyEvent->modifiers()&&keyEvent->key()==Qt::Key_Backspace)
             || ( ( keyEvent->modifiers() & Qt::ControlModifier ) && keyEvent->key() == Qt::Key_H ) )
     {
         QTextCursor t=_msgstrEdit->textCursor();
@@ -356,7 +485,6 @@ bool KAiderView::eventFilter(QObject * /*obj*/, QEvent *event)
         {
             int pos=t.position();
             QString str=_msgstrEdit->toPlainText();
-//             QString spclChars="abfnrtv'\"?\\";
             if(!str.isEmpty() && pos>0 && spclChars.contains(str.at(pos-1)))
             {
                 if(pos>1 && str.at(pos-2)=='\\' && !isMasked(str,pos-2))
@@ -409,10 +537,11 @@ void KAiderView::settingsChanged()
         else
         {
             _leds=new LedsWidget(this);
-            if (_catalog->isFuzzy(_currentEntry))
+            if (!_catalog->isApproved(_currentEntry))
                 _leds->ledFuzzy->on();
             if (_catalog->msgstr(_currentPos).isEmpty())
                 _leds->ledUntr->on();
+            cursorPositionChanged();
             insertWidget(2,_leds);
         }
     }
@@ -421,27 +550,46 @@ void KAiderView::settingsChanged()
 
 }
 
-void KAiderView::contentsChanged(int offset, int charsRemoved, int charsAdded )
+void KAiderView::cursorPositionChanged()
 {
-    if (KDE_ISUNLIKELY( _currentEntry==-1 || _msgstrEdit->toPlainText()==_oldMsgstr ))
+    if (_leds)
+        _leds->lblColumn->setText(i18nc("@info:label cursor position", "Column: %1", _msgstrEdit->textCursor().columnNumber()));
+}
+
+void KAiderView::contentsChanged(int offset, int charsRemoved, int charsAdded)
+{
+    kWarning()<<"!!!!!!!!!!!! offset"<<offset<<"charsRemoved"<<charsRemoved<<"_oldMsgstr"<<_oldMsgstr;
+    QString editText=_msgstrEdit->toPlainText();
+    if (KDE_ISUNLIKELY( _currentEntry==-1 || editText==_oldMsgstr ))
         return;
 
     DocPosition pos=_currentPos;
     pos.offset=offset;
+    //kWarning()<<"offset"<<offset<<"charsRemoved"<<charsRemoved<<"_oldMsgstr"<<_oldMsgstr;
 
-/*    kWarning()<<"offset"<<offset
-            <<"charsRemoved"<<charsRemoved
-            <<"charsAdded"<<charsAdded;*/
-    if (charsRemoved)
+#ifdef XLIFF
+    QString target=_catalog->targetWithTags(pos).string;
+
+    //protect from tag removal
+    if ((charsRemoved && target.mid(offset,charsRemoved).contains(TAGRANGE_IMAGE_SYMBOL))
+       ||(charsAdded && editText.mid(offset,charsAdded).contains(TAGRANGE_IMAGE_SYMBOL)))
     {
-//         kWarning()<<"here";
-        _catalog->push(new DelTextCmd(_catalog,pos,_oldMsgstr.mid(offset,charsRemoved)));
-//         kWarning()<<"here1";
+        //refresh
+        refreshMsgEdit(/*keepCursor*/true);
+        return;
     }
+#endif
 
-    _oldMsgstr=_msgstrEdit->toPlainText();//newStr becomes OldStr
+    m_modifiedAfterFind=true;
+
+
+    if (charsRemoved)
+        _catalog->push(new DelTextCmd(_catalog,pos,_oldMsgstr.mid(offset,charsRemoved)));
+
+    _oldMsgstr=editText;//newStr becomes OldStr
+    //kWarning()<<"char"<<editText[offset].unicode();
     if (charsAdded)
-        _catalog->push(new InsTextCmd(_catalog,pos,_oldMsgstr.mid(offset,charsAdded)));
+        _catalog->push(new InsTextCmd(_catalog,pos,editText.mid(offset,charsAdded)));
 
     if (_leds)
     {
@@ -454,21 +602,23 @@ void KAiderView::contentsChanged(int offset, int charsRemoved, int charsAdded )
     if (!_catalog->isApproved(_currentEntry))
         toggleApprovement(true);
 
-    // for mergecatalog (delete entry from index)
+    // for mergecatalog (remove entry from index)
     // and for statusbar
     emit signalChanged(pos.entry);
 }
 
-void KAiderView::approvedEntryDisplayed(bool approved, bool force)
+void KAiderView::approvedEntryDisplayed(bool approved)
 {
-    //kDebug()<<"fuzzy"<<_currentEntry<<fuzzy;
-    if (KDE_ISUNLIKELY( _currentEntry==-1 || (m_approvementState==approved && !force) ))
+    kWarning()<<"approvedEntryDisplayed. entry:"<<_currentEntry<<"approved:"<<approved;
+    if (KDE_ISUNLIKELY( _currentEntry==-1 ))
+    {
+        //kWarning()<<"approvedEntryDisplayed returning";
         return;
+    }
     m_approvementState=approved;
 
-    _msgstrEdit->setFontItalic(!approved);
-    if (force)
-        refreshMsgEdit();
+    m_msgstrHighlighter->setApprovementState(approved);
+    m_msgstrHighlighter->rehighlight();
 
     if (approved)
     {
@@ -496,8 +646,14 @@ void KAiderView::refreshMsgEdit(bool keepCursor)
     int pos=cursor.position();
     int anchor=cursor.anchor();
 
+#ifdef XLIFF
+    CatalogString targetWithTags=_catalog->targetWithTags(_currentPos);
+    QString target=targetWithTags.string;
+#else
     QString target=_catalog->target(_currentPos);
+#endif
     _oldMsgstr=target;
+
     if (!keepCursor && msgEdit.toPlainText()!=target)
     {
         pos=0;
@@ -507,63 +663,83 @@ void KAiderView::refreshMsgEdit(bool keepCursor)
 
     disconnect (msgEdit.document(), SIGNAL(contentsChange(int,int,int)), this, SLOT(contentsChanged(int,int,int)));
 
+#ifdef XLIFF
+    msgEdit.setContent(targetWithTags);
+#else
     //prevent undo tracking system from recording this 'action'
     msgEdit.document()->blockSignals(true);
     msgEdit.setPlainText(target);
     msgEdit.document()->blockSignals(false);
+#endif
 
     QTextCursor t=msgEdit.textCursor();
     t.movePosition(QTextCursor::Start);
     if (pos || anchor)
     {
+        //int anchorDiff=pos-anchor;
+/*        t.movePosition(QTextCursor::NextCharacter,QTextCursor::MoveAnchor,qMin(anchor,pos));
+        t.movePosition(QTextCursor::NextCharacter,QTextCursor::KeepAnchor,qMax(anchor,pos));
+        */
+        // I don't know why the following (more correct) code does not work
         t.movePosition(QTextCursor::NextCharacter,QTextCursor::MoveAnchor,anchor);
-        t.movePosition(QTextCursor::NextCharacter,QTextCursor::KeepAnchor,pos-anchor);
+        int length=pos-anchor;
+        if (length)
+            t.movePosition(length<0?QTextCursor::PreviousCharacter:QTextCursor::NextCharacter,QTextCursor::KeepAnchor,qAbs(length));
     }
     msgEdit.setTextCursor(t);
 
-    m_msgstrHighlighter->rehighlight();
+
+    approvedEntryDisplayed(_catalog->isApproved(_currentPos.entry));
+//     m_msgstrHighlighter->rehighlight(); done in approvedEntryDisplayed()
     connect (msgEdit.document(), SIGNAL(contentsChange(int,int,int)), this, SLOT(contentsChanged(int,int,int)));
 }
 
 
 //main function in this file :)
-void KAiderView::gotoEntry(const DocPosition& pos,int selection/*, bool updateHistory*/)
+void KAiderView::gotoEntry(const DocPosition& pos,int selection)
 {
     setUpdatesEnabled(false);
 
     _currentPos=pos;
     _currentEntry=pos.entry;
 
-    if (KDE_ISUNLIKELY( _catalog->pluralFormType(_currentEntry)==Gettext ))
+    if (KDE_ISUNLIKELY( _catalog->isPlural(_currentEntry)))
     {
-        if (KDE_ISUNLIKELY( _catalog->numberOfPluralForms()!=_tabbar->count() ))
+        if (KDE_ISUNLIKELY( _catalog->numberOfPluralForms()!=m_pluralTabBar->count() ))
         {
-            int i=_tabbar->count();
-            if (_catalog->numberOfPluralForms()>_tabbar->count())
+            int i=m_pluralTabBar->count();
+            if (_catalog->numberOfPluralForms()>m_pluralTabBar->count())
                 while (i<_catalog->numberOfPluralForms())
-                    _tabbar->addTab(i18nc("@title:tab","Plural Form %1",++i));
+                    m_pluralTabBar->addTab(i18nc("@title:tab","Plural Form %1",++i));
             else
                 while (i>_catalog->numberOfPluralForms())
-                    _tabbar->removeTab(i--);
+                    m_pluralTabBar->removeTab(i--);
         }
-        _tabbar->show();
-        _tabbar->blockSignals(true);
-        _tabbar->setCurrentIndex(_currentPos.form);
-        _tabbar->blockSignals(false);
+        m_pluralTabBar->show();
+        m_pluralTabBar->blockSignals(true);
+        m_pluralTabBar->setCurrentIndex(_currentPos.form);
+        m_pluralTabBar->blockSignals(false);
     }
     else
-        _tabbar->hide();
-
-    //force this because there are conditions when the
-    //signal isn't emitted (haven't identify them yet)
-    approvedEntryDisplayed(_catalog->isApproved(_currentEntry),false);
+        m_pluralTabBar->hide();
 
+#ifdef XLIFF
+    _msgidEdit->setContent(_catalog->sourceWithTags(_currentPos));
+    m_msgidHighlighter->rehighlight(); //explicitly because setContent disables signals
+#else
     _msgidEdit->setPlainText(_catalog->msgid(_currentPos)/*, _catalog->msgctxt(_currentIndex)*/);
-    //unwrap(_msgidEdit);
+#endif
 
+
+#ifdef UNWRAP_MSGID
+    unwrap(_msgidEdit);
+#endif
+
+    //kWarning()<<"calling refreshMsgEdit";
     refreshMsgEdit();//sets msgstredit text along the way
 
-    bool untrans=_catalog->msgstr(_currentPos).isEmpty();
+    QString targetString=_catalog->targetWithTags(_currentPos).string;
+    bool untrans=targetString.isEmpty();
     if (_leds)
     {
         if (untrans)
@@ -589,18 +765,27 @@ void KAiderView::gotoEntry(const DocPosition& pos,int selection/*, bool updateHi
         if (selection)
             t.movePosition(QTextCursor::NextCharacter,QTextCursor::KeepAnchor,selection);
     }
-    else
-    //what if msg starts with a tag?
-    if (KDE_ISUNLIKELY( !untrans && _catalog->msgstr(_currentPos).startsWith('<') ))
+    else if (!untrans)
     {
-        int offset=_catalog->msgstr(_currentPos).indexOf(QRegExp(">[^<]"));
-        if ( offset!=-1 )
-            t.movePosition(QTextCursor::NextCharacter,QTextCursor::MoveAnchor,offset+1);
+        //what if msg starts with a tag?
+        if (KDE_ISUNLIKELY( targetString.startsWith('<') ))
+        {
+            int offset=targetString.indexOf(QRegExp(">[^<]"));
+            if ( offset!=-1 )
+                t.movePosition(QTextCursor::NextCharacter,QTextCursor::MoveAnchor,offset+1);
+        }
+        else if (KDE_ISUNLIKELY( _catalog->msgstr(_currentPos).startsWith(TAGRANGE_IMAGE_SYMBOL) ))
+        {
+            int offset=targetString.indexOf(QRegExp("[^"+TAGRANGE_IMAGE_SYMBOL+']'));
+            if ( offset!=-1 )
+                t.movePosition(QTextCursor::NextCharacter,QTextCursor::MoveAnchor,offset+1);
+        }
     }
-        msgEdit->setTextCursor(t);
+
+    msgEdit->setTextCursor(t);
 
     //for undo/redo tracking
-    _oldMsgstr=_catalog->msgstr(_currentPos);
+    //_oldMsgstr=_catalog->msgstr(_currentPos); :::this is done in refreshMsgEdit()
 
     //prevent undo tracking system from recording this 'action'
 //     disconnect (_msgstrEdit->document(), SIGNAL(contentsChange(int,int,int)), this, SLOT(contentsChanged(int,int,int)));
@@ -609,9 +794,10 @@ void KAiderView::gotoEntry(const DocPosition& pos,int selection/*, bool updateHi
 
     _msgstrEdit->setFocus();
 
+    //kWarning()<<"anchor"<<t.anchor()<<"pos"<<t.position();
     setUpdatesEnabled(true);
 }
-
+/*
 void KAiderView::dragEnterEvent(QDragEnterEvent* event)
 {
     if(event->mimeData()->hasUrls() && event->mimeData()->urls().first().path().endsWith(".po"))
@@ -626,7 +812,7 @@ void KAiderView::dropEvent(QDropEvent *event)
 
 
 
-
+*/
 
 
 
@@ -640,11 +826,8 @@ void KAiderView::clearMsgStr()
 
     _currentPos.offset=0;
     _catalog->push(new DelTextCmd(_catalog,_currentPos,_catalog->msgstr(_currentPos)));
-    if (_catalog->isFuzzy(_currentEntry))
-    {
+    if (!_catalog->isApproved(_currentEntry))
         toggleApprovement(true);
-        approvedEntryDisplayed(true);
-    }
 
     gotoEntry(_currentPos);
     emit signalChanged(_currentEntry);
@@ -665,7 +848,7 @@ void KAiderView::toggleApprovement(bool approved)
         return;
 
     _catalog->push(new ToggleApprovementCmd(_catalog,_currentEntry,approved));
-    approvedEntryDisplayed(true);
+    approvedEntryDisplayed(approved);
 }
 
 
@@ -726,10 +909,9 @@ void KAiderView::msgid2msgstr()
         _catalog->push(new DelTextCmd(_catalog,pos,_catalog->target(_currentPos)));
         _oldMsgstr="";//newStr becomes OldStr
         _catalog->push(new InsTextCmd(_catalog,pos,text));
+        refreshMsgEdit();
         if (KDE_ISUNLIKELY( !_catalog->isApproved(pos.entry) ))
             toggleApprovement(true);
-        else
-            approvedEntryDisplayed(true, true);
     }
     else
     {
@@ -775,43 +957,6 @@ void KAiderView::insertTerm(const QString& term)
     _msgstrEdit->setFocus();
 }
 
-#if 0
-void KAiderView::replaceText(const QString& txt)
-{
-    if (KDE_ISUNLIKELY( txt==_msgstrEdit->toPlainText() || txt.isEmpty() ))
-        return;
-
-    if (!_catalog->msgstr(_currentPos).isEmpty())
-    {
-        _currentPos.offset=0;
-        _catalog->push(new DelTextCmd(_catalog,pos,_catalog->msgstr(pos)));
-    }
-
-    _catalog->push(new InsTextCmd(_catalog,pos,txt));
-
-#if 0
-    int oldOffset=_msgstrEdit->textCursor().position();
-    _msgstrEdit->insertPlainText(txt);
-
-    _msgstrEdit->setFocus();
-
-    if (KDE_ISUNLIKELY( _catalog->msgstr(_currentPos).size()==txt.size() ))
-        return;
-
-    _catalog->beginMacro(i18nc("@item Undo action item","Remove old translation"));
-    DocPosition pos=_currentPos;
-    pos.offset=0;
-    _catalog->push(new DelTextCmd(_catalog,pos,_catalog->msgstr(pos).left(oldOffset)));
-    pos.offset=txt.size();
-    _catalog->push(new DelTextCmd(_catalog,pos,_catalog->msgstr(pos).mid(txt.size())));
-
-    _catalog->endMacro();
-    pos.offset=0;
-#endif
-    //TODO separate into function!
-}
-#endif
-
 void KAiderView::tagMenu()
 {
     if (KDE_ISUNLIKELY( Project::instance()->markup().isEmpty() ))
@@ -829,7 +974,7 @@ void KAiderView::tagMenu()
     int pos=0;
     //tag.indexIn(en);
     int posInMsgStr=0;
-    QAction* txt(0);
+    QAction* txt=0;
     while ((pos=tag.indexIn(en,pos))!=-1)
     {
 /*        QString str(tag.cap(0));
@@ -855,3 +1000,5 @@ void KAiderView::tagMenu()
 
 
 
+
+#include "kaiderview.moc"
