@@ -1,7 +1,7 @@
 /*****************************************************************************
-  This file is part of KAider
+  This file is part of Lokalize
 
-  Copyright (C) 2007	  by Nick Shaforostoff <shafff@ukr.net>
+  Copyright (C) 2007-2008  by Nick Shaforostoff <shafff@ukr.net>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -41,12 +41,12 @@
 
 #define WEBQUERY_ENABLE
 
-class QAction;
+class KAction;
 class KRecentFilesAction;
 class ProjectModel;
 namespace GlossaryNS{class Glossary;}
 namespace TM{class SelectJob;}
-class KAider;
+class EditorWindow;
 // class WebQueryThread;
 // #include "webquerythread.h"
 #include <threadweaver/Job.h>
@@ -63,7 +63,7 @@ class KAider;
 
 /**
  * Singleton object that represents project.
- * It is shared between KAider 'mainwindows' that use the same project file.
+ * It is shared between EditorWindow 'mainwindows' that use the same project file.
  * Keeps project's KDirModel, Glossary and kross::actions
  *
  * GUI for config handling is implemented in prefs.cpp
@@ -96,9 +96,7 @@ public:
     QString glossaryPath()const{return absolutePath(glossaryTbx());}
     GlossaryNS::Glossary* glossary()const{return m_glossary;}
 
-    QStringList webQueryScripts() const;
-
-    const QList<QAction*>& projectActions();
+    QStringList scriptsList() const;
 
 private slots:
     void initLater();
@@ -109,7 +107,6 @@ private:
     QString absolutePath(const QString&)const;
 
 public slots:
-    void load(const KUrl &file){load(file.path());}//convenience overload for recent projects action
 
     void populateDirModel();
     void populateGlossary();
@@ -118,20 +115,15 @@ public slots:
 #endif
 //     void populateKrossActions();
 
-    void openProjectWindow();
-
     void deleteScanJob(ThreadWeaver::Job*);
     void dispatchSelectJob(ThreadWeaver::Job*);//used fr safety: what mainwindow has been closed?
-//     void slotTMWordsIndexed(ThreadWeaver::Job*);
     void showTMManager();
-    void showTM();
     void showGlossary();
     void defineNewTerm(QString en=QString(),QString target=QString());
 
 
-    void registerEditor(KAider* e){m_editors<<e;}
-    void unregisterEditor(KAider* e){m_editors.remove(m_editors.indexOf(e));}
-    void openInExisting(const KUrl& u);
+    void registerEditor(EditorWindow* e){m_editors<<e;}
+    void unregisterEditor(EditorWindow* e){m_editors.remove(m_editors.indexOf(e));}
 
 
 private:
@@ -159,17 +151,17 @@ private:
 //     QTime scanningTime;
 //     WebQueryController* m_webQueryController;
 //     WebQueryThread m_webQueryThread;
-    QList<QAction*> m_projectActions;
+    QList<KAction*> m_projectActions;
     KRecentFilesAction* _openRecentProject;
 
-    QVector<KAider*> m_editors;
+    QVector<EditorWindow*> m_editors;
 };
 
 inline
 ProjectModel* Project::model()
 {
     if (KDE_ISUNLIKELY(!m_model))
-        m_model=new ProjectModel;
+        m_model=new ProjectModel(this);
 
     return m_model;
 }
