@@ -1,11 +1,10 @@
 /***************************************************************************
- *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2006                                               *
+ *   copyright (C) 2002-2008                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -25,7 +24,8 @@
  * @see UMLObject
  * Bugs and comments to uml-devel@lists.sf.net or http://bugs.kde.org
  */
-class UMLAttribute : public UMLClassifierListItem {
+class UMLAttribute : public UMLClassifierListItem
+{
     Q_OBJECT
 public:
     /**
@@ -88,7 +88,7 @@ public:
      *
      * @return  The initial value of the Atrtibute.
      */
-    QString getInitialValue();
+    QString getInitialValue() const;
 
     /**
      * Sets the initial value of the UMLAttribute.
