@@ -14,6 +14,12 @@
 // qt/kde includes
 #include <QMap>
 #include <kdebug.h>
+
+// must be located here for win32 msvc (see kdevcppparser/position.h)
+#include "kdevcppparser/lexer.h"
+#include "kdevcppparser/driver.h"
+#include "kdevcppparser/cpptree2uml.h"
+
 // app includes
 #include "import_utils.h"
 #include "../umlobject.h"
@@ -25,9 +31,7 @@
 #include "../attribute.h"
 #include "../template.h"
 #include "../association.h"
-#include "kdevcppparser/lexer.h"
-#include "kdevcppparser/driver.h"
-#include "kdevcppparser/cpptree2uml.h"
+
 
 // static members
 CppDriver * CppImport::ms_driver;
@@ -87,10 +91,10 @@ void CppImport::initialize() {
     ms_driver->addIncludePath( "/usr/include/c++" );
     ms_driver->addIncludePath( "/usr/include/g++" );
     ms_driver->addIncludePath( "/usr/local/include" );
-    QStringList incPathList = Import_Utils::includePathList();
+    const QStringList incPathList = Import_Utils::includePathList();
     if (incPathList.count()) {
-        QStringList::Iterator end(incPathList.end());
-        for (QStringList::Iterator i(incPathList.begin()); i != end; ++i) {
+        QStringList::ConstIterator end(incPathList.end());
+        for (QStringList::ConstIterator i(incPathList.begin()); i != end; ++i) {
             ms_driver->addIncludePath( *i );
         }
 
