@@ -1,24 +1,23 @@
 /***************************************************************************
- *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2004-2006                                               *
+ *   copyright (C) 2004-2008                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 #ifndef DIALOG_UTILS_H
 #define DIALOG_UTILS_H
 
-#include <qstring.h>
+#include <QtCore/QString>
 
 class QGroupBox;
 class QGridLayout;
 class QLabel;
-class QLineEdit;
 class UMLWidget;
+class KLineEdit;
 
 /**
  * Dialog utilities.
@@ -30,19 +29,19 @@ namespace Dialog_Utils {
 /**
  * Create a labeled text lineedit widget.
  *
- * @param containingBox         The containing QGroupBox.
+ * @param containingBox         The containing QGroupBox (unused).
  * @param layout                The QGridLayout to use.
  * @param row                   The row number within the QGridLayout.
  * @param label                 The QLabel object allocated (return value)
  * @param labelText             The label text.
- * @param editField             The QLineEdit object allocated (return value)
+ * @param editField             The KLineEdit object allocated (return value)
  * @param editFieldText         Initialization text in the editField (optional.)
- * @return a pointer to the QLineEdit so you can setFocus() if necessary
+ * @return a pointer to the KLineEdit so you can setFocus() if necessary
  */
-QLineEdit* makeLabeledEditField(QGroupBox *containingBox, QGridLayout *layout, int row,
+KLineEdit* makeLabeledEditField(QGroupBox *containingBox, QGridLayout *layout, int row,
                                 QLabel * &label, const QString& labelText,
-                                QLineEdit * &editField,
-                                const QString& editFieldText = QString::null);
+                                KLineEdit * &editField,
+                                const QString& editFieldText = QString());
 
 /**
  * Helper function for requesting a name for an UMLWidget using a dialog.
@@ -57,6 +56,7 @@ QLineEdit* makeLabeledEditField(QGroupBox *containingBox, QGridLayout *layout, i
 void askNameForWidget(UMLWidget * &targetWidget, const QString& dialogTitle,
                       const QString& dialogPrompt, const QString& defaultName);
 
+
 }
 
 #endif
