@@ -5,7 +5,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2003-2007                                               *
+ *   copyright (C) 2003-2008                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -22,21 +22,24 @@
 #include "uniqueid.h"
 #include "clipboard/idchangelog.h"
 
-UMLEnum::UMLEnum(const QString& name, Uml::IDType id) : UMLClassifier(name, id) {
+UMLEnum::UMLEnum(const QString& name, Uml::IDType id) : UMLClassifier(name, id)
+{
     init();
 }
 
-UMLEnum::~UMLEnum() {
+UMLEnum::~UMLEnum()
+{
     m_List.clear();
 }
 
-bool UMLEnum::operator==( UMLEnum & rhs ) {
+bool UMLEnum::operator==(const UMLEnum & rhs )
+{
     return UMLClassifier::operator==(rhs);
 }
 
-void UMLEnum::copyInto(UMLEnum *rhs) const
+void UMLEnum::copyInto(UMLObject *lhs) const
 {
-    UMLClassifier::copyInto(rhs);
+    UMLClassifier::copyInto(lhs);
 }
 
 UMLObject* UMLEnum::clone() const
@@ -47,12 +50,14 @@ UMLObject* UMLEnum::clone() const
     return clone;
 }
 
-void UMLEnum::init() {
+void UMLEnum::init()
+{
     m_BaseType = Uml::ot_Enum;
     setStereotype( "enum" );
 }
 
-UMLObject* UMLEnum::createEnumLiteral(const QString& name) {
+UMLObject* UMLEnum::createEnumLiteral(const QString& name)
+{
     Uml::IDType id = UniqueID::gen();
     QString currentName;
     if (name.isNull())  {
@@ -91,11 +96,11 @@ UMLObject* UMLEnum::createEnumLiteral(const QString& name) {
     return newEnumLiteral;
 }
 
-UMLObject* UMLEnum::addEnumLiteral(const QString &name, Uml::IDType id) {
+UMLObject* UMLEnum::addEnumLiteral(const QString &name, Uml::IDType id)
+{
     UMLObject *el = UMLCanvasObject::findChildObject(name);
     if (el != NULL) {
-        kDebug() << "UMLEnum::addEnumLiteral: " << name
-                  << " is already present" << endl;
+        uDebug() << name << " is already present" << endl;
         return el;
     }
     UMLEnumLiteral* literal = new UMLEnumLiteral(this, name, id);
@@ -106,11 +111,11 @@ UMLObject* UMLEnum::addEnumLiteral(const QString &name, Uml::IDType id) {
     return literal;
 }
 
-bool UMLEnum::addEnumLiteral(UMLEnumLiteral* literal, IDChangeLog* Log /* = 0*/) {
+bool UMLEnum::addEnumLiteral(UMLEnumLiteral* literal, IDChangeLog* Log /* = 0*/)
+{
     QString name = (QString)literal->getName();
     if (findChildObject(name) == NULL) {
-        literal->parent()->removeChild(literal);
-        this->insertChild(literal);
+        literal->setParent(this);
         m_List.append(literal);
         UMLObject::emitModified();
         emit enumLiteralAdded(literal);
@@ -123,11 +128,11 @@ bool UMLEnum::addEnumLiteral(UMLEnumLiteral* literal, IDChangeLog* Log /* = 0*/)
     return false;
 }
 
-bool UMLEnum::addEnumLiteral(UMLEnumLiteral* literal, int position) {
+bool UMLEnum::addEnumLiteral(UMLEnumLiteral* literal, int position)
+{
     QString name = (QString)literal->getName();
     if (findChildObject(name) == NULL) {
-        literal->parent()->removeChild(literal);
-        this->insertChild(literal);
+        literal->setParent(this);
         if ( position >= 0 && position <= (int)m_List.count() )  {
             m_List.insert(position,literal);
         } else {
@@ -141,9 +146,10 @@ bool UMLEnum::addEnumLiteral(UMLEnumLiteral* literal, int position) {
     return false;
 }
 
-int UMLEnum::removeEnumLiteral(UMLEnumLiteral* literal) {
-    if (!m_List.remove(literal)) {
-        kDebug() << "can't find att given in list" << endl;
+int UMLEnum::removeEnumLiteral(UMLEnumLiteral* literal)
+{
+    if (!m_List.removeAll(literal)) {
+        uDebug() << "can not find att given in list";
         return -1;
     }
     emit enumLiteralRemoved(literal);
@@ -155,27 +161,29 @@ int UMLEnum::removeEnumLiteral(UMLEnumLiteral* literal) {
     return m_List.count();
 }
 
-int UMLEnum::enumLiterals() {
+int UMLEnum::enumLiterals()
+{
     return m_List.count();
 }
 
-void UMLEnum::signalEnumLiteralRemoved(UMLClassifierListItem *elit) {
+void UMLEnum::signalEnumLiteralRemoved(UMLClassifierListItem *elit)
+{
     emit enumLiteralRemoved(elit);
 }
 
-void UMLEnum::saveToXMI(QDomDocument& qDoc, QDomElement& qElement) {
+void UMLEnum::saveToXMI(QDomDocument& qDoc, QDomElement& qElement)
+{
     QDomElement enumElement = UMLObject::save("UML:Enumeration", qDoc);
     // save enum literals
     UMLClassifierListItemList enumLiterals = getFilteredList(Uml::ot_EnumLiteral);
-    UMLClassifierListItem* pEnumLiteral = 0;
-    for (UMLClassifierListItemListIt it(enumLiterals);
-         (pEnumLiteral = it.current()) != NULL; ++it) {
+    foreach (UMLClassifierListItem* pEnumLiteral , enumLiterals ) {
         pEnumLiteral->saveToXMI(qDoc, enumElement);
     }
     qElement.appendChild(enumElement);
 }
 
-bool UMLEnum::load(QDomElement& element) {
+bool UMLEnum::load(QDomElement& element)
+{
     QDomNode node = element.firstChild();
     while( !node.isNull() ) {
         if (node.isComment()) {
@@ -192,10 +200,9 @@ bool UMLEnum::load(QDomElement& element) {
             }
             m_List.append(pEnumLiteral);
         } else if (tag == "stereotype") {
-            kDebug() << "UMLEnum::load(" << m_Name
-            << "): losing old-format stereotype." << endl;
+            uDebug() << m_Name << ": losing old-format stereotype." << endl;
         } else {
-            kWarning() << "unknown child type in UMLEnum::load" << endl;
+            uWarning() << "unknown child type in UMLEnum::load";
         }
         node = node.nextSibling();
     }//end while
@@ -203,4 +210,13 @@ bool UMLEnum::load(QDomElement& element) {
 }
 
 
+UMLClassifierListItem* UMLEnum::makeChildObject(const QString& xmiTag)
+{
+    UMLClassifierListItem* pObject = NULL;
+    if (Uml::tagEq(xmiTag, "EnumerationLiteral") || Uml::tagEq( xmiTag, "EnumLiteral")) {
+        pObject = new UMLEnumLiteral(this);
+    }
+    return pObject;
+}
+
 #include "enum.moc"
