@@ -132,7 +132,7 @@ public:
     /**
      * Overrides the standard operation.
      */
-    virtual void moveEvent(QMoveEvent */*m*/);
+    virtual void moveEvent(QMoveEvent *m);
 
     /**
      * Used to cleanup any other widget it may need to delete.
@@ -184,6 +184,13 @@ public:
      */
     int topMargin();
 
+    /**
+     * Sets the y position of the bottom of the vertical line.
+     *
+     * @param yPosition The y coordinate for the bottom of the line.
+     */
+    void setEndLine(int yPosition);
+
     /**
      * Returns the end Y co-ord of the seq. line.
      *
@@ -243,7 +250,7 @@ public slots:
     /**
      * Handles a popup menu selection.
      */
-    void slotMenuSelection(int sel);
+    void slotMenuSelection(QAction* action);
 
     /**
      * Handles a color change signal.
