@@ -1,5 +1,4 @@
 /***************************************************************************
- *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
@@ -12,18 +11,17 @@
 
 #include "refactoringassistant.h"
 
-#include "../umlnamespace.h"
-#include "../umldoc.h"
-#include "../classifier.h"
-#include "../attribute.h"
-#include "../operation.h"
-#include "../dialogs/classpropdlg.h"
-#include "../dialogs/umloperationdialog.h"
-#include "../dialogs/umlattributedialog.h"
-#include "../object_factory.h"
+#include "umlnamespace.h"
+#include "umldoc.h"
+#include "classifier.h"
+#include "attribute.h"
+#include "operation.h"
+#include "dialogs/classpropdlg.h"
+#include "dialogs/umloperationdialog.h"
+#include "dialogs/umlattributedialog.h"
+#include "object_factory.h"
 
-#include <qpoint.h>
-#include <qpopupmenu.h>
+#include <QtCore/QPoint>
 
 #include <typeinfo>
 #include <kstandarddirs.h>
@@ -36,8 +34,9 @@ using std::type_info;
 
 
 RefactoringAssistant::RefactoringAssistant( UMLDoc *doc, UMLClassifier *obj, QWidget *parent, const char *name ):
-        KListView( parent, name ), m_doc( doc )
+        K3ListView( parent), m_doc( doc )
 {
+    setObjectName(name);
     loadPixmaps();
 
     setRootIsDecorated( true );
@@ -54,11 +53,11 @@ RefactoringAssistant::RefactoringAssistant( UMLDoc *doc, UMLClassifier *obj, QWi
 
     addColumn("Name ");
 
-    m_menu = new QPopupMenu(this);
+    m_menu = new QMenu(this);
 
-    connect(this,SIGNAL(doubleClicked(QListViewItem*)),this,SLOT(itemExecuted(QListViewItem*)));
-    connect(this,SIGNAL(contextMenu(KListView*, QListViewItem*, const QPoint&)),
-            this,SLOT(showContextMenu(KListView*,QListViewItem*,const QPoint&)));
+    connect(this,SIGNAL(doubleClicked(Q3ListViewItem*)),this,SLOT(itemExecuted(Q3ListViewItem*)));
+    connect(this,SIGNAL(contextMenu(K3ListView*, Q3ListViewItem*, const QPoint&)),
+            this,SLOT(showContextMenu(K3ListView*,Q3ListViewItem*,const QPoint&)));
 
     resize(300,400);
 
@@ -82,46 +81,45 @@ void RefactoringAssistant::refactor( UMLClassifier *obj )
     }
 
     addClassifier( obj, 0, true, true, true );
-    QListViewItem *item = firstChild();
+    Q3ListViewItem *item = firstChild();
     item->setOpen(true);
     for( item = item->firstChild(); item ; item = item->nextSibling() )
         item->setOpen(true);
 }
 
 
-UMLObject* RefactoringAssistant::findUMLObject( const QListViewItem *item )
+UMLObject* RefactoringAssistant::findUMLObject( const Q3ListViewItem *item )
 {
-    QListViewItem *i = const_cast<QListViewItem*>(item);
-    if( m_umlObjectMap.find(i) == m_umlObjectMap.end() )
+    if (item == NULL)
+        return NULL;
+    Q3ListViewItem *i = const_cast<Q3ListViewItem*>(item);
+    if ( m_umlObjectMap.find(i) == m_umlObjectMap.end() )
     {
-        kWarning()<<"RefactoringAssistant::findUMLObject( QListViewItem *item )"
+        uWarning()<<"RefactoringAssistant::findUMLObject( QListViewItem *item )"
         <<"item with text "<<item->text(0)<<"not found in uml map!"<<endl;
-        return 0L;
+        return NULL;
     }
     return m_umlObjectMap[i];
-
 }
 
-QListViewItem* RefactoringAssistant::findListViewItem( const UMLObject *obj )
+Q3ListViewItem* RefactoringAssistant::findListViewItem( const UMLObject *obj )
 {
     UMLObjectMap::iterator end(m_umlObjectMap.end());
     for( UMLObjectMap::iterator it(m_umlObjectMap.begin()) ; it != end ; ++it )
         if( (*it).second == obj )
             return (*it).first;
-    kWarning() << "RefactoringAssistant::findListViewItem:"
-    << "object id " << ID2STR(obj->getID())
-    << "does not have a ListItem" << endl;
-    return 0L;
+    uWarning() << "object id " << ID2STR(obj->getID()) << "does not have a ListItem" << endl;
+    return NULL;
 }
 
 
-void RefactoringAssistant::itemExecuted( QListViewItem *item )
+void RefactoringAssistant::itemExecuted( Q3ListViewItem *item )
 {
     UMLObject *o = findUMLObject( item );
     if(o) editProperties( );
 }
 
-void RefactoringAssistant::setVisibilityIcon( QListViewItem *item , const UMLObject *obj )
+void RefactoringAssistant::setVisibilityIcon( Q3ListViewItem *item , const UMLObject *obj )
 {
     switch(obj->getVisibility())
     {
@@ -145,7 +143,7 @@ void RefactoringAssistant::umlObjectModified( const UMLObject *obj )
 {
     if( !obj )
         obj = dynamic_cast<const UMLObject*>(sender());
-    QListViewItem *item = findListViewItem( obj );
+    Q3ListViewItem *item = findListViewItem( obj );
     if( !item )
         return;
     item->setText( 0, obj->getName() );
@@ -162,20 +160,19 @@ void RefactoringAssistant::operationAdded( UMLClassifierListItem *o )
     UMLClassifier *c = dynamic_cast<UMLClassifier*>(op->parent());
     if(!c)
     {
-        kWarning() << "RefactoringAssistant::operationAdded(" << op->getName()
-            << ") - Parent of operation is not a classifier!" << endl;
+        uWarning() << op->getName() << " - Parent of operation is not a classifier!" << endl;
         return;
     }
-    QListViewItem *item = findListViewItem( c );
+    Q3ListViewItem *item = findListViewItem( c );
     if( !item )
     {
         return;
     }
-    for( QListViewItem *folder = item->firstChild(); folder; folder = folder->nextSibling() )
+    for( Q3ListViewItem *folder = item->firstChild(); folder; folder = folder->nextSibling() )
     {
         if( folder->text(1) == "operations" )
         {
-            item = new KListViewItem( folder, op->getName() );
+            item = new K3ListViewItem( folder, op->getName() );
             m_umlObjectMap[item] = op;
             connect( op, SIGNAL( modified() ), this, SLOT( umlObjectModified() ) );
             setVisibilityIcon( item, op );
@@ -187,7 +184,7 @@ void RefactoringAssistant::operationAdded( UMLClassifierListItem *o )
 void RefactoringAssistant::operationRemoved( UMLClassifierListItem *o )
 {
     UMLOperation *op = static_cast<UMLOperation*>(o);
-    QListViewItem *item = findListViewItem( op );
+    Q3ListViewItem *item = findListViewItem( op );
     if( !item )
     {
         return;
@@ -204,20 +201,19 @@ void RefactoringAssistant::attributeAdded( UMLClassifierListItem *a )
     UMLClassifier *c = dynamic_cast<UMLClassifier*>(att->parent());
     if(!c)
     {
-        kWarning() << "RefactoringAssistant::attributeAdded(" << att->getName()
-            << ") - Parent is not a class!" << endl;
+        uWarning() << att->getName() << " - Parent is not a class!" << endl;
         return;
     }
-    QListViewItem *item = findListViewItem( c );
+    Q3ListViewItem *item = findListViewItem( c );
     if( !item )
     {
         return;
     }
-    for( QListViewItem *folder = item->firstChild(); folder; folder = folder->nextSibling() )
+    for( Q3ListViewItem *folder = item->firstChild(); folder; folder = folder->nextSibling() )
     {
         if( folder->text(1) == "attributes" )
         {
-            item = new KListViewItem( folder, att->getName() );
+            item = new K3ListViewItem( folder, att->getName() );
             m_umlObjectMap[item] = att;
             connect( att, SIGNAL( modified() ), this, SLOT( umlObjectModified() ) );
             setVisibilityIcon( item, att );
@@ -229,7 +225,7 @@ void RefactoringAssistant::attributeAdded( UMLClassifierListItem *a )
 void RefactoringAssistant::attributeRemoved( UMLClassifierListItem *a )
 {
     UMLAttribute *att = static_cast<UMLAttribute*>(a);
-    QListViewItem *item = findListViewItem( att );
+    Q3ListViewItem *item = findListViewItem( att );
     if( !item )
     {
         return;
@@ -241,7 +237,7 @@ void RefactoringAssistant::attributeRemoved( UMLClassifierListItem *a )
 
 void RefactoringAssistant::editProperties( )
 {
-    QListViewItem *item = selectedItem();
+    Q3ListViewItem *item = selectedItem();
     if( item )
     {
         UMLObject *o = findUMLObject( item );
@@ -251,11 +247,11 @@ void RefactoringAssistant::editProperties( )
 
 void RefactoringAssistant::editProperties( UMLObject *obj )
 {
-    KDialogBase *dia(0);
+    KDialog *dia(0);
     Uml::Object_Type t = obj->getBaseType();
     if (t == Uml::ot_Class || t == Uml::ot_Interface)
     {
-        dia = new ClassPropDlg(this,obj,0,true);
+        dia = new ClassPropDlg(this,obj,true);
     }
     else if (t == Uml::ot_Operation)
     {
@@ -267,7 +263,7 @@ void RefactoringAssistant::editProperties( UMLObject *obj )
     }
     else
     {
-        kWarning()<<"RefactoringAssistant::editProperties( UMLObject *o ) caled for unknown type "<<typeid(*obj).name()<<endl;
+        uWarning()<<"RefactoringAssistant::editProperties( UMLObject *o ) caled for unknown type "<<typeid(*obj).name();
         return;
     }
     if( dia && dia->exec() )
@@ -277,48 +273,58 @@ void RefactoringAssistant::editProperties( UMLObject *obj )
     delete dia;
 }
 
-void RefactoringAssistant::showContextMenu(KListView* ,QListViewItem *item, const QPoint &p)
+QAction* RefactoringAssistant::createAction(const QString text, const char * method)
 {
+    QAction* action = new QAction(this);
+    action->setText(text);
+    connect(action, SIGNAL(triggered()), this, method);
+    return action;
+}
+
+void RefactoringAssistant::showContextMenu(K3ListView* ,Q3ListViewItem *item, const QPoint &p)
+{
+    if (item == NULL)
+        return;
     m_menu->clear();
     UMLObject *obj = findUMLObject( item );
-    if(obj)
+    if (obj)
     {// Menu for UMLObjects
         Uml::Object_Type t = obj->getBaseType();
         if (t == Uml::ot_Class)
         {
-            m_menu->insertItem(i18n("Add Base Class"),this,SLOT(addBaseClassifier()));
-            m_menu->insertItem(i18n("Add Derived Class"),this,SLOT(addDerivedClassifier()));
-            //          m_menu->insertItem(i18n("Add Interface Implementation"),this,SLOT(addInterfaceImplementation()));
-            m_menu->insertItem(i18n("Add Operation"),this,SLOT(createOperation()));
-            m_menu->insertItem(i18n("Add Attribute"),this,SLOT(createAttribute()));
+            m_menu->addAction(createAction(i18n("Add Base Class"), SLOT(addBaseClassifier())));
+            m_menu->addAction(createAction(i18n("Add Derived Class"), SLOT(addDerivedClassifier())));
+            // m_menu->addAction(createAction(i18n("Add Interface Implementation"), SLOT(addInterfaceImplementation())));
+            m_menu->addAction(createAction(i18n("Add Operation"), SLOT(createOperation())));
+            m_menu->addAction(createAction(i18n("Add Attribute"), SLOT(createAttribute())));
         }
         else if (t == Uml::ot_Interface)
         {
-            m_menu->insertItem(i18n("Add Base Interface"),this,SLOT(addSuperClassifier()));
-            m_menu->insertItem(i18n("Add Derived Interface"),this,SLOT(addDerivedClassifier()));
-            m_menu->insertItem(i18n("Add Operation"),this,SLOT(createOperation()));
+            m_menu->addAction(createAction(i18n("Add Base Interface"), SLOT(addSuperClassifier())));
+            m_menu->addAction(createAction(i18n("Add Derived Interface"), SLOT(addDerivedClassifier())));
+            m_menu->addAction(createAction(i18n("Add Operation"), SLOT(createOperation())));
         }
-        //              else
-        //              {
-        //              kDebug()<<"No context menu for objects of type "<<typeid(*obj).name()<<endl;
-        //              return;
-        //              }
-        m_menu->insertSeparator();
-        m_menu->insertItem(i18n("Properties"),this,SLOT(editProperties()));
+        // else
+        // {
+        //     uDebug()<<"No context menu for objects of type "<<typeid(*obj).name();
+        //     return;
+        // }
+        m_menu->addSeparator();
+        m_menu->addAction(createAction(i18n("Properties"), SLOT(editProperties())));
     }
     else
     {//menu for other ViewItems
-        if( item->text(1) == "operations" )
+        if ( item->text(1) == "operations" )
         {
-            m_menu->insertItem(i18n("Add Operation"),this,SLOT(createOperation()));
+            m_menu->addAction(createAction(i18n("Add Operation"), SLOT(createOperation())));
         }
-        else if( item->text(1) == "attributes" )
+        else if ( item->text(1) == "attributes" )
         {
-            m_menu->insertItem(i18n("Add Attribute"),this,SLOT(createAttribute()));
+            m_menu->addAction(createAction(i18n("Add Attribute"), SLOT(createAttribute())));
         }
         else
         {
-            kWarning()<<"RefactoringAssistant::showContextMenu() "
+            uWarning()<<"RefactoringAssistant::showContextMenu() "
             <<"called for extraneous item"<<endl;
             return;
         }
@@ -328,17 +334,17 @@ void RefactoringAssistant::showContextMenu(KListView* ,QListViewItem *item, cons
 
 void RefactoringAssistant::addBaseClassifier()
 {
-    QListViewItem *item = selectedItem();
+    Q3ListViewItem *item = selectedItem();
     if(!item)
     {
-        kWarning()<<"RefactoringAssistant::addBaseClassifier() "
+        uWarning()<<"RefactoringAssistant::addBaseClassifier() "
         <<"called with no item selected"<<endl;
         return;
     }
     UMLObject *obj = findUMLObject( item );
     if( !dynamic_cast<UMLClassifier*>(obj) )
     {
-        kWarning()<<"RefactoringAssistant::addBaseClassifier() "
+        uWarning()<<"RefactoringAssistant::addBaseClassifier() "
         <<"called for a non-classifier object"<<endl;
         return;
     }
@@ -351,15 +357,15 @@ void RefactoringAssistant::addBaseClassifier()
     m_doc->createUMLAssociation( obj, super, Uml::at_Generalization );
     //////////////////////   Manually add the classifier to the assitant - would be nicer to do it with
     /////////////////////    a signal, like operations and attributes
-    QListViewItem *baseFolder = item->firstChild();
+    Q3ListViewItem *baseFolder = item->firstChild();
     while( baseFolder->text(0) != i18n("Base Classifiers") )
         baseFolder = baseFolder->nextSibling();
     if(!baseFolder)
     {
-        kWarning()<<"Cannot find Base Folder"<<endl;
+        uWarning()<<"Cannot find Base Folder";
         return;
     }
-    item = new KListViewItem( baseFolder, super->getName() );
+    item = new K3ListViewItem( baseFolder, super->getName() );
     item->setPixmap(0,m_pixmaps.Generalization);
     item->setExpandable( true );
     m_umlObjectMap[item] = super;
@@ -369,17 +375,17 @@ void RefactoringAssistant::addBaseClassifier()
 
 void RefactoringAssistant::addDerivedClassifier()
 {
-    QListViewItem *item = selectedItem();
+    Q3ListViewItem *item = selectedItem();
     if(!item)
     {
-        kWarning()<<"RefactoringAssistant::addDerivedClassifier() "
+        uWarning()<<"RefactoringAssistant::addDerivedClassifier() "
         <<"called with no item selected"<<endl;
         return;
     }
     UMLObject *obj = findUMLObject( item );
     if( !dynamic_cast<UMLClassifier*>(obj) )
     {
-        kWarning()<<"RefactoringAssistant::addDerivedClassifier() "
+        uWarning()<<"RefactoringAssistant::addDerivedClassifier() "
         <<"called for a non-classifier object"<<endl;
         return;
     }
@@ -393,15 +399,15 @@ void RefactoringAssistant::addDerivedClassifier()
 
     //////////////////////   Manually add the classifier to the assitant - would be nicer to do it with
     /////////////////////    a signal, like operations and attributes
-    QListViewItem *derivedFolder = item->firstChild();
+    Q3ListViewItem *derivedFolder = item->firstChild();
     while( derivedFolder->text(0) != i18n("Derived Classifiers") )
         derivedFolder = derivedFolder->nextSibling();
     if(!derivedFolder)
     {
-        kWarning()<<"Cannot find Derived Folder"<<endl;
+        uWarning()<<"Cannot find Derived Folder";
         return;
     }
-    item = new KListViewItem( derivedFolder, derived->getName() );
+    item = new K3ListViewItem( derivedFolder, derived->getName() );
     item->setPixmap(0,m_pixmaps.Subclass);
     item->setExpandable( true );
     m_umlObjectMap[item] = derived;
@@ -411,10 +417,10 @@ void RefactoringAssistant::addDerivedClassifier()
 
 void RefactoringAssistant::addInterfaceImplementation()
 {
-    kWarning()<<"RefactoringAssistant::addInterfaceImplementation()"
+    uWarning()<<"RefactoringAssistant::addInterfaceImplementation()"
     <<"not implemented... finish addSuperClassifier() first!!"<<endl;
     return;
-    //  QListViewItem *item = selectedListViewItem( );
+    //  Q3ListViewItem *item = selectedListViewItem( );
     //  UMLObject *obj = findUMLObject( item );
     //  if( !dynamic_cast<UMLClassifier*>(obj) )
     //          return;
@@ -427,10 +433,10 @@ void RefactoringAssistant::addInterfaceImplementation()
 
 void RefactoringAssistant::createOperation()
 {
-    QListViewItem *item = selectedItem();
+    Q3ListViewItem *item = selectedItem();
     if(!item)
     {
-        kWarning()<<"RefactoringAssistant::createOperation() "
+        uWarning()<<"RefactoringAssistant::createOperation() "
         <<"called with no item selected"<<endl;
         return;
     }
@@ -442,10 +448,10 @@ void RefactoringAssistant::createOperation()
 
 void RefactoringAssistant::createAttribute()
 {
-    QListViewItem *item = selectedItem();
+    Q3ListViewItem *item = selectedItem();
     if(!item)
     {
-        kWarning()<<"RefactoringAssistant::createAttribute() "
+        uWarning()<<"RefactoringAssistant::createAttribute() "
         <<"called with no item selected"<<endl;
         return;
     }
@@ -456,16 +462,16 @@ void RefactoringAssistant::createAttribute()
 }
 
 
-void RefactoringAssistant::addClassifier( UMLClassifier *classifier, QListViewItem *parent, bool addSuper, bool addSub, bool recurse)
+void RefactoringAssistant::addClassifier( UMLClassifier *classifier, Q3ListViewItem *parent, bool addSuper, bool addSub, bool recurse)
 {
-    QListViewItem *classifierItem, *item;
+    Q3ListViewItem *classifierItem, *item;
     if( parent )
     {
         classifierItem = parent;
     }
     else
     {
-        classifierItem= new KListViewItem( this, classifier->getName() );
+        classifierItem= new K3ListViewItem( this, classifier->getName() );
         m_umlObjectMap[classifierItem] = classifier;
     }
 
@@ -479,13 +485,12 @@ void RefactoringAssistant::addClassifier( UMLClassifier *classifier, QListViewIt
         connect( classifier, SIGNAL(attributeRemoved(UMLClassifierListItem*)),
                  this, SLOT(attributeRemoved(UMLClassifierListItem*)));
 
-        QListViewItem *attsFolder = new KListViewItem( classifierItem, i18n("Attributes"), "attributes" );
+        Q3ListViewItem *attsFolder = new K3ListViewItem( classifierItem, i18n("Attributes"), "attributes" );
         attsFolder->setPixmap(0,SmallIcon("folder_green_open"));
         attsFolder->setExpandable( true );
         UMLAttributeList atts = klass->getAttributeList();
-        for( UMLAttribute *att = atts.first(); att; att = atts.next() )
-        {
-            attributeAdded( att );
+        for( UMLAttributeListIt alit( atts ) ; alit.hasNext(); ) {
+            attributeAdded( alit.next() );
         }
 
     }
@@ -496,24 +501,22 @@ void RefactoringAssistant::addClassifier( UMLClassifier *classifier, QListViewIt
     connect( classifier, SIGNAL(operationRemoved(UMLClassifierListItem*)),
              this, SLOT(operationRemoved(UMLClassifierListItem*)));
 
-    QListViewItem *opsFolder = new KListViewItem( classifierItem, i18n("Operations"), "operations" );
+    Q3ListViewItem *opsFolder = new K3ListViewItem( classifierItem, i18n("Operations"), "operations" );
     opsFolder->setPixmap(0,SmallIcon("folder_blue_open"));
     opsFolder->setExpandable( true );
     UMLOperationList ops(classifier->getOpList());
-    for( UMLOperation *op = ops.first(); op ; op = ops.next() )
-    {
+    foreach ( UMLOperation* op, ops ) {
         operationAdded( op );
     }
 
     //if add parents
     if(addSuper)
     {
-        QListViewItem *superFolder = new KListViewItem( classifierItem, i18n("Base Classifiers") );
+        Q3ListViewItem *superFolder = new K3ListViewItem( classifierItem, i18n("Base Classifiers") );
         superFolder->setExpandable( true );
         UMLClassifierList super = classifier->findSuperClassConcepts();
-        for( UMLClassifier *cl = super.first(); cl ; cl = super.next() )
-        {
-            item = new KListViewItem( superFolder, cl->getName() );
+        foreach ( UMLClassifier* cl, super ) {
+            item = new K3ListViewItem( superFolder, cl->getName() );
             item->setPixmap(0,m_pixmaps.Generalization);
             item->setExpandable( true );
             m_umlObjectMap[item] = cl;
@@ -527,12 +530,11 @@ void RefactoringAssistant::addClassifier( UMLClassifier *classifier, QListViewIt
     if(addSub)
     {
         //add derived classifiers
-        QListViewItem *derivedFolder = new KListViewItem( classifierItem, i18n("Derived Classifiers") );
+        Q3ListViewItem *derivedFolder = new K3ListViewItem( classifierItem, i18n("Derived Classifiers") );
         derivedFolder->setExpandable( true );
         UMLClassifierList derived = classifier->findSubClassConcepts();
-        for( UMLClassifier *d = derived.first(); d ; d = derived.next() )
-        {
-            item = new KListViewItem( derivedFolder, d->getName() );
+        foreach ( UMLClassifier* d, derived ) {
+            item = new K3ListViewItem( derivedFolder, d->getName() );
             item->setPixmap(0,m_pixmaps.Subclass);
             item->setExpandable( true );
             m_umlObjectMap[item] = d;
@@ -558,7 +560,7 @@ bool RefactoringAssistant::acceptDrag(QDropEvent *event) const
     RefactoringAssistant *me = const_cast<RefactoringAssistant*>(this);
 
     //ok, check if the move is valid
-    QListViewItem *movingItem = 0, *afterme = 0, *parentItem = 0;
+    Q3ListViewItem *movingItem = 0, *afterme = 0, *parentItem = 0;
     me->findDrop(event->pos(), parentItem, afterme);
     for( movingItem = firstChild(); movingItem != 0; movingItem = movingItem->itemBelow() )
     {
@@ -566,24 +568,24 @@ bool RefactoringAssistant::acceptDrag(QDropEvent *event) const
             break;
     }
     if(!movingItem || !parentItem)
-    {   kDebug()<<"moving/parent items not found - can't accept drag!"<<endl;
+    {   uDebug()<<"moving/parent items not found - cannot accept drag!";
         return false;
     }
 
     UMLObject *movingObject;
     if( !(movingObject = me->findUMLObject(movingItem)) )
     {
-        kDebug()<<"Moving object not found in uml map!"<<movingItem->text(0)<<endl;
+        uDebug()<<"Moving object not found in uml map!"<<movingItem->text(0);
         return false;
     }
     Uml::Object_Type t = movingObject->getBaseType();
     if (t != Uml::ot_Attribute && t != Uml::ot_Operation)
     {
-        kDebug()<<"only operations and attributes are movable! - return false"<<endl;
+        uDebug()<<"only operations and attributes are movable! - return false";
         return false;
     }
 
-    kDebug()<<"parent item is "<<parentItem->text(0)<<endl;
+    uDebug()<<"parent item is "<<parentItem->text(0);
     UMLObject *parentObject = me->findUMLObject(parentItem);
     if( parentObject && dynamic_cast<UMLClassifier*>(parentObject) )
     {
@@ -598,7 +600,7 @@ bool RefactoringAssistant::acceptDrag(QDropEvent *event) const
         }
         else
         {
-            kDebug()<<"moving to item "<<parentItem->text(0)<<" -- "<<parentItem->text(1)<<" not valid"<<endl;
+            uDebug()<<"moving to item "<<parentItem->text(0)<<" -- "<<parentItem->text(1)<<" not valid";
             return false;
         }
     }
@@ -608,17 +610,17 @@ bool RefactoringAssistant::acceptDrag(QDropEvent *event) const
         return true;
     }
 
-    kDebug()<<"how did I get here? return false!!"<<endl;
+    uDebug()<<"how did I get here? return false!!";
     return false;
 }
 
 
-void RefactoringAssistant::movableDropEvent (QListViewItem* parentItem, QListViewItem* afterme)
+void RefactoringAssistant::movableDropEvent (Q3ListViewItem* parentItem, Q3ListViewItem* afterme)
 {
     //when dropping on a class, we have to put the item in the appropriate folder!
     UMLObject *movingObject;
     UMLClassifier *newClassifier;
-    QListViewItem *movingItem;
+    Q3ListViewItem *movingItem;
 
     for( movingItem = firstChild(); movingItem != 0; movingItem = movingItem->itemBelow() )
     {
@@ -627,7 +629,7 @@ void RefactoringAssistant::movableDropEvent (QListViewItem* parentItem, QListVie
     }
     if( !movingItem || (movingItem == afterme) || !(movingObject = findUMLObject(movingItem)) )
     {
-        kWarning()<<"Moving item not found or dropping after itself or item not found in uml obj map. aborting. (drop had already been accepted)"<<endl;
+        uWarning()<<"Moving item not found or dropping after itself or item not found in uml obj map. aborting. (drop had already been accepted)";
         return;
     }
     Uml::Object_Type t = movingObject->getBaseType();
@@ -641,18 +643,18 @@ void RefactoringAssistant::movableDropEvent (QListViewItem* parentItem, QListVie
         }
         if(!newClassifier)
         {
-            kWarning()<<"New parent of object is not a Classifier - Drop had already been accepted - check!"<<endl;
+            uWarning()<<"New parent of object is not a Classifier - Drop had already been accepted - check!";
             return;
         }
     }
     if (t == Uml::ot_Operation)
-    {kDebug()<<"moving operation"<<endl;
+    {uDebug()<<"moving operation";
         UMLOperation *op = static_cast<UMLOperation*>(movingObject);
         if(newClassifier->checkOperationSignature(op->getName(), op->getParmList()))
         {
-            QString msg = QString(i18n("An operation with that signature already exists in %1.\n")).arg(newClassifier->getName())
+            QString msg = i18n("An operation with that signature already exists in %1.\n", newClassifier->getName())
                           +
-                          QString(i18n("Choose a different name or parameter list." ));
+                          i18n("Choose a different name or parameter list.");
             KMessageBox::error(this, msg, i18n("Operation Name Invalid"), false);
             return;
         }
@@ -662,7 +664,7 @@ void RefactoringAssistant::movableDropEvent (QListViewItem* parentItem, QListVie
         newClassifier->addOperation( op );
     }
     else if (t == Uml::ot_Attribute)
-    {kDebug()<<"moving attribute - not implemented"<<endl;
+    {uDebug()<<"moving attribute - not implemented";
         //              UMLAttribute *att = static_cast<UMLAttribute*>(movingObject);
         //              if(!newClassifier->checkAttributeSignature(att))
         //              {
@@ -691,11 +693,7 @@ void RefactoringAssistant::loadPixmaps()
     m_pixmaps.Implementation.load( dataDir + "CVimplementation_var.png" );
     m_pixmaps.Generalization.load( dataDir + "generalisation.png" );
     m_pixmaps.Subclass.load( dataDir + "uniassociation.png" );
-
-
 }
 
 
-
-
 #include "refactoringassistant.moc"
