@@ -5,33 +5,29 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2006                                               *
+ *   copyright (C) 2002-2008                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 #ifndef UMLLISTVIEW_H
 #define UMLLISTVIEW_H
 
-#include <qdom.h>
-#include <qpixmap.h>
-#include <klistview.h>
+#include <QtXml/QDomDocument>
+#include <QtXml/QDomElement>
+#include <QtGui/QTreeWidget>
+#include <QtGui/QTreeWidgetItem>
+
+#include <k3listview.h>
+
 #include "umlnamespace.h"
 #include "umllistviewitemlist.h"
+#include "icon_utils.h"
 
-/**
- * This is one of the main classes used in this program.
- * Information is displayed here in a tree view.  No objects are created
- * here.  A call to @ref UMLDoc make any additions/deletion or updates to
- * objects.  This class will then wait for a signal before updating the tree view.
- *
- * @short  Displays the list view for the program.
- * @author Paul Hensgen    <phensgen@techie.com>
- * Bugs and comments to uml-devel@lists.sf.net or http://bugs.kde.org
- */
-
+class QEvent;
 class QMouseEvent;
-class QContextMenuEvent;
+class QFocusEvent;
 class QKeyEvent;
+class QDropEvent;
 class IDChangeLog;
 class ListPopupMenu;
 class UMLClassifier;
@@ -40,16 +36,28 @@ class UMLListViewItem;
 class UMLView;
 class UMLObject;
 class UMLClassifierListItem;
+class UMLDragData;
 
-class UMLListView : public KListView {
+/**
+ * This is one of the main classes used in this program.
+ * Information is displayed here in a tree view. No objects are created
+ * here. A call to @ref UMLDoc make any additions/deletion or updates to
+ * objects. This class will then wait for a signal before updating the tree view.
+ *
+ * @short  Displays the list view for the program.
+ * @author Paul Hensgen    <phensgen@techie.com>
+ * Bugs and comments to uml-devel@lists.sf.net or http://bugs.kde.org
+ */
+class UMLListView : public K3ListView
+{
     Q_OBJECT
 public:
 
     /**
      * Constructs the tree view.
      *
-     * @param parent    The parent to this.
-     * @param name              The internal name for this class.
+     * @param parent   The parent to this.
+     * @param name     The internal name for this class.
      */
     UMLListView(QWidget *parent,const char *name);
 
@@ -62,9 +70,9 @@ public:
      * Sets the document his is associated with.  This is important as
      * this is required as to setup the callbacks.
      *
-     * @param d         The document to associate with this class.
+     * @param doc   The document to associate with this class.
      */
-    void setDocument(UMLDoc * d);
+    void setDocument(UMLDoc * doc);
 
     /**
      * Carries out initalisation of attributes in class.
@@ -74,32 +82,32 @@ public:
     /**
      * Set the current view to the given view.
      *
-     * @param v         The current view.
+     * @param view   The current view.
      */
-    void setView(UMLView* v);
+    void setView(UMLView* view);
 
     /**
      * Get selected items.
      *
-     * @param ItemList  List of UMLListViewItems returned.
-     * @return          The number of selected items.
+     * @param ItemList   List of UMLListViewItems returned.
+     * @return           The number of selected items.
      */
     int getSelectedItems(UMLListViewItemList &ItemList);
 
     /**
      * Get selected items, but only root elements selected (without children).
      *
-     * @param ItemList  List of UMLListViewItems returned.
-     * @return          The number of selected items.
+     * @param ItemList   List of UMLListViewItems returned.
+     * @return           The number of selected items.
      */
     int getSelectedItemsRoot(UMLListViewItemList &ItemList);
 
     /**
      * Create a listview item for an existing diagram.
      *
-     * @param v         The existing diagram.
+     * @param view   The existing diagram.
      */
-    UMLListViewItem* createDiagramItem(UMLView *v);
+    UMLListViewItem* createDiagramItem(UMLView *view);
 
     /**
      * CHECK - This is perhaps redundant since the
@@ -155,11 +163,6 @@ public:
      */
     int getSelectedCount();
 
-    /**
-     * Returns the correct pixmap for the given type.
-     */
-    QPixmap & getPixmap( Uml::Icon_Type type );
-
     /**
      * Returns the document pointer.  Called by the UMLListViewItem class.
      */
@@ -172,19 +175,19 @@ public:
      * Method will take care of signalling anyone needed on creation of new item.
      * e.g. UMLDoc if an UMLObject is created.
      */
-    void addNewItem(UMLListViewItem * parent, Uml::ListView_Type type);
+    void addNewItem( UMLListViewItem * parent, Uml::ListView_Type type );
 
     /**
      * Find an UMLObject in the listview.
      *
-     * @param p         Pointer to the object to find in the list view.
-     * @return  Pointer to the UMLObject found or NULL if not found.
+     * @param p   Pointer to the object to find in the list view.
+     * @return    Pointer to the UMLObject found or NULL if not found.
      */
     UMLListViewItem * findUMLObject(const UMLObject *p) const;
 
     /**
      * Searches through the tree for the item which represents the diagram given
-     * @param the diagram to search for
+     * @param v  the diagram to search for
      * @return the item which represents the diagram
      */
     UMLListViewItem * findView(UMLView *v);
@@ -192,8 +195,8 @@ public:
     /**
      * Searches through the tree for the item with the given ID.
      *
-     * @param id                The ID to search for.
-     * @return  The item with the given ID or NULL if not found.
+     * @param id   The ID to search for.
+     * @return     The item with the given ID or NULL if not found.
      */
     UMLListViewItem * findItem(Uml::IDType id);
 
@@ -206,7 +209,7 @@ public:
     /**
      * Changes the icon for the given UMLObject to the given icon.
      */
-    void changeIconOf(UMLObject *o, Uml::Icon_Type to);
+    void changeIconOf(UMLObject *o, Icon_Utils::Icon_Type to);
 
     /**
      * Creates a UMLObject out of the given list view item.
@@ -221,7 +224,7 @@ public:
     /**
      * Creates a diagram out of the given list view item.
      */
-    void createDiagram( UMLListViewItem * item, Uml::Diagram_Type type );
+    UMLView* createDiagram( UMLListViewItem * item, Uml::Diagram_Type type );
 
     /**
      * Returns a unique name for a diagram.
@@ -236,11 +239,11 @@ public:
     /**
      * Cancel rename event has occurred for the given item.
      */
-    void  cancelRename( QListViewItem * item );
+    void  cancelRename( Q3ListViewItem * item );
 
     /**
      * Set the variable m_bStartedCut
-     * to indicate that selection should be deleted 
+     * to indicate that selection should be deleted
      * in slotCutSuccessful()
      */
     void setStartedCut(bool startedCut);
@@ -268,7 +271,7 @@ public:
     /**
      * Called for informing the list view that an item was renamed.
      */
-    bool itemRenamed(QListViewItem* item , int col);
+    bool itemRenamed(Q3ListViewItem* item , int col);
 
     void closeDatatypesFolder();
 
@@ -310,17 +313,20 @@ protected:
      */
     bool m_bCreatingChildObject;
 
-    QPixmap m_Pixmaps[Uml::N_ICONTYPES];
-
     bool eventFilter(QObject *o, QEvent *e);
     void contentsMouseReleaseEvent(QMouseEvent * me);
     void contentsMousePressEvent(QMouseEvent *me);
+    void contentsMouseMoveEvent(QMouseEvent* me);
     void contentsMouseDoubleClickEvent(QMouseEvent * me);
     void focusOutEvent ( QFocusEvent * fe);
-    QDragObject* dragObject();
-    void startDrag();
+
+    UMLDragData* getDragData();
+
     bool acceptDrag (QDropEvent* event) const;
     void keyPressEvent(QKeyEvent *);
+    void dragEnterEvent(QDragEnterEvent* event);
+    void dragMoveEvent(QDragMoveEvent* event);
+    void dropEvent(QDropEvent* event);
 
     /**
      * This methods looks for a object in a folder an its subfolders recursive.
@@ -336,15 +342,10 @@ protected:
      */
     static bool isExpandable(Uml::ListView_Type lvt);
 
-    /**
-     *  Loads the pixmaps to use in the list items.
-     */
-    void loadPixmaps();
-
     /**
      * Deletes all child-items of @p parent.
      */
-    void deleteChildrenOf( QListViewItem *parent );
+    void deleteChildrenOf( Q3ListViewItem *parent );
 
     /**
      * Delete a listview item.
@@ -358,7 +359,7 @@ protected:
      * Adds a new operation, attribute or template item to a classifier, identical to
      * childObjectAdded(obj) but with an explicit parent.
      * @param child the child object
-     * @param parent the parent object 
+     * @param parent the parent object
      */
     void childObjectAdded(UMLClassifierListItem* child, UMLClassifier* parent);
 
@@ -379,7 +380,7 @@ public slots:
 
     /**
      * renames a diagram in the list view
-     * @param the id of the renamed diagram
+     * @param id    the id of the renamed diagram
      */
     void slotDiagramRenamed(Uml::IDType id);
 
@@ -427,32 +428,32 @@ public slots:
     /**
      * Called when a right mouse button menu has an item selected
      */
-    void popupMenuSel(int sel);
+    void popupMenuSel(QAction* action);
 
     /**
      * Something has been dragged and dropped onto the list view
      */
-    void slotDropped(QDropEvent* de, QListViewItem* parent, QListViewItem* item);
+    void slotDropped(QDropEvent* de, Q3ListViewItem* parent, Q3ListViewItem* item);
 
     /**
      * calls updateFolder() on the item to update the icon to open
      */
-    void slotExpanded(QListViewItem* item);
+    void slotExpanded(Q3ListViewItem* item);
 
     /**
      * calls updateFolder() on the item to update the icon to closed
      */
-    void slotCollapsed(QListViewItem* item);
+    void slotCollapsed(Q3ListViewItem* item);
 
     /**
      * Open all items in the list view
      */
-    void expandAll(QListViewItem *item);
+    void expandAll(Q3ListViewItem *item);
 
     /**
      * Close all items in the list view
      */
-    void collapseAll(QListViewItem *item);
+    void collapseAll(Q3ListViewItem *item);
 
     /**
      *  Connects to the signal that @ref UMLApp emits when a
@@ -468,6 +469,13 @@ private:
     UMLListViewItem* recursiveSearchForView(UMLListViewItem* folder,
                                             Uml::ListView_Type type, Uml::IDType id);
 
+    /**
+     * Set the background color.
+     */
+    void setBackgroundColor(const QColor & color);
+
+    QPoint m_dragStartPosition;
+
 };
 
 #endif
