@@ -5,16 +5,21 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2006                                               *
+ *   copyright (C) 2002-2007                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 #include "umlobjectlist.h"
 #include "umlobject.h"
-#include <kdebug.h>
-#include <klocale.h>
 
-void UMLObjectList::copyInto(UMLObjectList *rhs) const {
+UMLObjectList::UMLObjectList()
+{}
+
+UMLObjectList::~UMLObjectList()
+{}
+
+void UMLObjectList::copyInto(UMLObjectList *rhs) const
+{
     // Don't copy yourself.
     if (rhs == this) return;
 
@@ -23,16 +28,18 @@ void UMLObjectList::copyInto(UMLObjectList *rhs) const {
     // Suffering from const; we shall not modify our object.
     UMLObjectList *tmp = new UMLObjectList(*this);
 
-    UMLObject *item;
-    for (item = tmp->first(); item; item = tmp->next() )
+    UMLObject *item = NULL;
+    for (UMLObjectListIt oit( *tmp ); oit.hasNext() ; )
     {
+        item = oit.next();
         rhs->append(item->clone());
     }
     delete tmp;
 }
 
 
-UMLObjectList* UMLObjectList::clone() const {
+UMLObjectList* UMLObjectList::clone() const
+{
     UMLObjectList *clone = new UMLObjectList();
     copyInto(clone);
     return clone;
@@ -40,3 +47,5 @@ UMLObjectList* UMLObjectList::clone() const {
 
 
 
+
+
